@@ -6,7 +6,6 @@
 
 #include "OssAudioRenderer.h"
 
-#include "AudioQueue.h"
 #include "avifile.h"
 #include "avm_cpuinfo.h"
 #include "avm_output.h"
@@ -225,13 +224,13 @@ void* OssAudioRenderer::doAudioOut(void* arg)
 	if (wsize > a.m_uiWriteSize)
             wsize = a.m_uiWriteSize;
 #if 0
-	static int64_t las = longcount();
-	int64_t tlas = longcount();
-	AVM_WRITE("OSS audio renderer", "diff %f    %f\n", to_float(tlas, las), a.getRendererBufferTime());
+	static int64_t las = avm_get_time_us();
+	int64_t tlas = avm_get_time_us();
+	AVM_WRITE("OSS audio renderer", "diff %f    %f\n", avm_get_time_diff(tlas, las), a.getRendererBufferTime());
 	las = tlas;
 #endif
 	int result = a.m_pQueue->Read(0, wsize, &a.m_AudioMix);
-	//printf("wtime %f   %f\n", to_float(longcount(), ct), to_float(longcount(), a.m_lTimeStart) );
+	//printf("wtime %f   %f\n", avm_get_time_diff(avm_get_time_us(), ct), avm_get_time_diff(avm_get_time_us(), a.m_lTimeStart) );
 
 	//AVM_WRITE("audio renderer", "Wrote %d bytes\n", result);
 	if (result < (int) a.m_uiWriteSize)
@@ -243,13 +242,16 @@ void* OssAudioRenderer::doAudioOut(void* arg)
 		// this should assure the we will actually
                 // hear the very last bytes from buffer
 		const uint_t sz = 32768/4;
-		uint32_t* d = new uint32_t[sz];
 		int r = 0;
 		if (a.m_Owf.wBitsPerSample <= 8)
 		    r = 0x80808080;
-		for (uint_t i = 0; i < sz; i++) d[i] = r;
-		a.m_AudioMix.Mix(0, d, sz*4);
-		delete[] d;
+		uint32_t* d = new uint32_t[sz];
+		if (d)
+		{
+		    for (uint_t i = 0; i < sz; i++) d[i] = r;
+		    a.m_AudioMix.Mix(0, d, sz*4);
+		    delete[] d;
+		}
 	    }
 	}
 	else
@@ -331,7 +333,7 @@ double OssAudioRenderer::getRendererBufferTime() const
     {
 	printf("GETOPTR  %f   %f   %f    %d   %d   %d\n",
 	       info.bytes / m_dOwfBPS,
-	       to_float(longcount(), m_lTimeStart), m_dAudioRealpos,
+	       avm_get_time_diff(avm_get_time_us(), m_lTimeStart), m_dAudioRealpos,
 	       info.bytes, info.blocks, info.ptr);
     }
 #endif
