@@ -23,7 +23,6 @@
 
 #include "avm_cpuinfo.h"
 #include "avm_creators.h"
-#include "avm_except.h"
 #include "avm_fourcc.h"
 #include "avm_output.h"
 #include "utils.h"
@@ -49,56 +48,60 @@ AVM_BEGIN_NAMESPACE;
 AviPlayer::AviPlayer(const char* filename, int depth, const char* subname,
                      unsigned int flags,
 		     const char* vcodec, const char* acodec)
-    :m_Drop("Drop", 50), m_Quality("Quality", 25)
+    :
+    m_pAudioRenderer(0),
+    m_pKillhandler(0),
+    m_pAudiofunc(0),
+    m_pClip(0),
+    m_pClipAudio(0),
+    m_pVideostream(0),
+    m_pAudiostream(0),
+    m_Drop("Drop", 50),
+    m_Quality("Quality", 25),
+
+    m_Filename(filename),
+    m_Subfilename(subname ? subname : ""),
+    m_pSubtitles(0),
+    m_pSubline(0),
+
+    m_fAsync(0.),
+    m_fSubAsync(0.),
+    m_iFramesVideo(0),
+    m_iFrameDrop(0),
+    m_iLockCount(0),
+    m_llTimeStart(0),
+    m_dFrameStart(0),
+    m_dLastFrameStart(0),
+    m_dLastAudioSync(0.),
+    m_fLastDiff(0.),
+    m_fLastSyncTime(0.),
+    m_fLastSleepTime(0.),
+
+    m_pVideoThread(0),
+    m_pAudioThread(0),
+    m_pDecoderThread(0),
+
+    m_uiPgPrevPos(~0U),
+    m_llPgPrevTime(0),
+
+    m_dVframetime(0.04),
+    m_iWidth(0),
+    m_iHeight(0),
+    m_iDepth(depth),
+    m_CSP(24),
+
+    m_bQualityAuto(false),
+    m_bVideoBuffered(false),
+    m_bVideoDirect(false),
+    m_bDropping(false),
+    m_bPaused(false),
+    m_bInitialized(false),
+    m_bQuit(false),
+    m_bHangup(false),
+    m_bBuffering(false),
+    m_bCallSync(false),
+    m_bConstructed(false)
 {
-    m_pVideostream = 0;
-    m_pAudiostream = 0;
-    m_bInitialized = false;
-    m_bHangup = false;
-    m_bPaused = false;
-    m_bQuit = false;
-    m_bBuffering = false;
-    m_bCallSync = false;
-    m_bConstructed = false;
-    m_bDropping = false;
-    m_iLockCount = 0;
-    m_lTimeStart = 0;
-    m_dFrameStart = 0;
-    m_dLastFrameStart = 0;
-    m_iFramesVideo = 0;
-    m_iFrameDrop = 0;
-    m_pClip = 0;
-    m_pClipAudio = 0;
-    m_fLastSyncTime = 0.0;
-    m_fLastDiff = 0.;
-    m_pAudiofunc = 0;
-    m_pAudioRenderer = 0;
-    m_fAsync = 0.0;
-    m_fSubAsync = 0.0;
-    m_dVframetime = 0.04;
-    m_dLastAudioSync = 0.0;
-    m_fLastSleepTime = 0.0;
-    m_bCallSync = false;
-    m_Filename = filename;
-    m_Subfilename = subname ? subname : "";
-    m_iDepth = depth;
-    m_pKillhandler = 0;
-    m_pSubtitles = 0;
-    m_pSubline = 0;
-    m_iWidth = 0;
-    m_iHeight = 0;
-    m_CSP = 24;
-    m_pAudioThread =
-	m_pVideoThread =
-	m_pDecoderThread = 0;
-
-    m_bQualityAuto = false;
-    m_bVideoBuffered = false;
-    m_bVideoDirect = false;
-
-    m_uiPgPrevPos = ~0;
-    m_lPgPrevTime = 0LL;
-
     if (vcodec && strlen(vcodec))
 	m_vcodec = vcodec;
     if (acodec && strlen(acodec))
@@ -120,11 +123,16 @@ AviPlayer::AviPlayer(const char* filename, int depth, const char* subname,
 
     m_bVideoAsync = (getenv("AVIPLAY_VIDEO_ASYNC") != 0) ? true : false;
 
-    int AVIPLAY_DEBUG = (getenv("AVIPLAY_DEBUG")   != 0) ? 1 : 0;
-
-    AVM_WRITE("aviplay", "Debug is on %d\n", AVIPLAY_DEBUG);
-
-    if (AVIPLAY_DEBUG) avm::out.setDebugLevel("aviplayxx", 2);
+    const char* ad = getenv("AVIPLAY_DEBUG");
+    if (ad)
+    {
+	int AVIPLAY_DEBUG = atoi(ad);
+	if (AVIPLAY_DEBUG)
+	{
+	    AvmOutput()->setDebugLevel("aviplayxx", 4);
+	    AVM_WRITE("aviplay", "Debug is on %d\n", AVIPLAY_DEBUG);
+	}
+    }
 
     if (m_bVideoAsync)
 	AVM_WRITE("aviplay", 1, "Video is running asynchronously\n");
@@ -249,7 +257,7 @@ void AviPlayer::construct()
 
     m_iFramesVideo = 0;
     m_iFrameDrop = 0;
-    m_lTimeStart = 0;
+    m_llTimeStart = 0;
     m_bQuit = false;
     m_bConstructed = true;
     //	short fs;
@@ -322,7 +330,6 @@ int AviPlayer::InitSubtitles(const char* filename)
 	if (m_pSubtitles)
 	    subtitle_close(m_pSubtitles);
 	char* fn = NULL;
-
 	int fd = subtitle_filename(filename, &fn);
 	if (fd >= 0)
 	{
@@ -415,7 +422,7 @@ void AviPlayer::Start()
     else if (!m_pVideostream)
 	return; // nothing to do
 
-    m_lLastTimeStart = longcount();
+    m_llLastTimeStart = avm_get_time_us();
     m_Drop.clear();
     m_bQuit = false;
     m_bPaused = false;
@@ -466,11 +473,8 @@ void AviPlayer::Pause(bool state)
     }
     else
     {
-	if (m_pAudioRenderer)
-	{
-	    if (m_pAudioRenderer->Pause(state) != 0)
-		return;
-	}
+	if (m_pAudioRenderer && (m_pAudioRenderer->Pause(state) != 0))
+	    return;
 	m_bPaused = state;
 	m_bBuffering = false;
 	unlockThreads();
@@ -587,7 +591,7 @@ int AviPlayer::ReseekExact(double pos)
 	if (pos2 < 0.0)
 	{
 	    pos2 = pos = 0.0;
-	    AVM_WRITE("aviplay", "WARNING: reseek_exact  pos2<0!\n");
+	    AVM_WRITE("aviplay", "Warning: reseek_exact  pos2<0!\n");
 	    r = -1;
 	}
 
@@ -595,7 +599,7 @@ int AviPlayer::ReseekExact(double pos)
 	{
 	    if (pos2 > pos && pos2 > (m_pVideostream->GetTime(0) + 0.001))
 	    {
-		AVM_WRITE("aviplay", "WARNING: reseek_exact: pos2>pos! %f %f   %f\n", pos2, pos, m_pVideostream->GetTime(0));
+		AVM_WRITE("aviplay", "Warning: reseek_exact: pos2>pos! %f %f   %f\n", pos2, pos, m_pVideostream->GetTime(0));
 		r = -1;
 	    }
 	    drawFrame(false);
@@ -643,7 +647,7 @@ int AviPlayer::PrevKeyFrame()
 	{
 	    framepos_t cpos = m_pVideostream->GetPos();
 	    framepos_t npos = m_pVideostream->SeekToPrevKeyFrame();
-	    if (to_float(longcount(), m_lPgPrevTime) < 0.3)
+	    if (avm_get_time_diff(avm_get_time_us(), m_llPgPrevTime) < 0.3)
 	    {
 		framepos_t p = npos;
 		while (npos > 0 && npos >= m_uiPgPrevPos)
@@ -659,7 +663,7 @@ int AviPlayer::PrevKeyFrame()
 		m_pVideostream->Seek(npos);
 		npos = m_pVideostream->SeekToPrevKeyFrame();
 	    }
-	    m_lPgPrevTime = longcount();
+	    m_llPgPrevTime = avm_get_time_us();
 	    m_uiPgPrevPos = npos;
 
 	    if (npos != m_pVideostream->ERR)
@@ -830,7 +834,7 @@ void AviPlayer::createAudioRenderer()
     char* arends = arend;
     while (arends && !m_pAudioRenderer)
     {
-	WAVEFORMATEX Owf = MyOwf;
+	WAVEFORMATEX Owf(MyOwf);
 	AVM_WRITE("aviplay", "Will try audio renderers in this order: %s\n", arends);
 
 	if (m_pAudiofunc)
