@@ -151,6 +151,7 @@ protected:
     IReadStream* m_pAudiostream;
     Statistic m_Drop;
     Statistic m_Quality;
+
     avm::string m_Filename;
     avm::string m_Subfilename;
     avm::string m_vcodec;
@@ -164,14 +165,11 @@ protected:
     int m_iFramesVideo;		// just counters
     int m_iFrameDrop;
     int m_iLockCount;
-
-    int m_iWidth;
-    int m_iHeight;
 				// these vars are used in syncing video with time
-    int64_t m_lTimeStart;	// timestamp of moment when we started playing
+    int64_t m_llTimeStart;	// timestamp of moment when we started playing
 				// updated after each reseek or pause
-    int64_t m_lLastVideoSync;	// stamp for last video time in sync
-    int64_t m_lLastTimeStart;	// timestamp of the last displayed frame
+    int64_t m_llLastVideoSync;	// stamp for last video time in sync
+    int64_t m_llLastTimeStart;	// timestamp of the last displayed frame
     double m_dFrameStart;	// precise position of video at time_start ( needed
 				// for timing of video-only streams )
     double m_dLastFrameStart;	// precise position of video at last frame
@@ -184,12 +182,11 @@ protected:
     PthreadTask* m_pAudioThread;   // performs audio output and sync
     PthreadTask* m_pDecoderThread; // performs video decompression and caching
 
-    uint_t m_iEffectiveUid;	// effective user id
-    uint_t m_iEffectiveGid;	// effective group id
+    int m_iEffectiveUid;	// effective user id
+    int m_iEffectiveGid;	// effective group id
 
     framepos_t m_uiPgPrevPos;
-    int64_t m_lPgPrevTime;
-
+    int64_t m_llPgPrevTime;
 
     PthreadMutex m_ThreadMut[THREAD_LAST]; // 3 mutexes
     PthreadCond m_ThreadCond[THREAD_LAST]; // 3 conditions
@@ -200,6 +197,8 @@ protected:
 
     double m_dVideoSeekDest;
     double m_dVframetime;
+    int m_iWidth;
+    int m_iHeight;
     int m_iDepth;
     uint_t m_CSP;               // used colorspace by renderer
 
