@@ -291,7 +291,7 @@ int AviPlayer::Set(...)
 	    createVideoRenderer();
 
 	    double posn = m_pVideostream->SeekTimeToKeyFrame(pos);
-	    if (m_pAudiostream && posn + 5 < pos)
+	    if (m_pAudiostream && ((posn + 5) < pos))
 		Reseek(posn); // complet reseek
 	}
 	unlockThreads();
@@ -511,26 +511,16 @@ int AviPlayer::setAudioUrl(const char* url)
 {
     lockThreads("SetAudioUrl");
 
-    IReadFile* newClipAudio = 0;
+    // compare Url's from the end (as filename could be either
+    // fullpath or just filename
+    uint_t u = strlen(url);
+    uint_t f = m_Filename.size();
 
-    try
-    {
-	// compare Url's from the end (as filename could be either
-	// fullpath or just filename
-	int u = strlen(url);
-	int f = m_Filename.size();
-
-	while (u > 0 && f > 0)
-	    if (url[--u] != m_Filename[--f])
-		break;
-	newClipAudio = (u == 0 || f == 0) ? m_pClip : CreateReadFile(url);
-
-	//printf("CLUPO %s %s %p %p\n", m_Filename.c_str(), url, m_pClip, newClipAudio);
-    }
-    catch (FatalError& e)
-    {
-	e.Print();
-    }
+    while (u > 0 && f > 0)
+	if (url[--u] != m_Filename[--f])
+	    break;
+    IReadFile* newClipAudio =
+	(u == 0 || f == 0) ? m_pClip : CreateReadFile(url);
 
     if (newClipAudio)
     {
