@@ -188,7 +188,8 @@ int AviReadHandler::init(const char* pszFile)
     bih.SetDirection(1);
     bih.biCompression = ('3'<<24) | ('V'<<16) | ('I' << 8) | 'D';
     ash.fccHandler = bih.biCompression;
-    m_Streams.push_back(new AviReadStream(this, ash, 0, (char*)&bih, sizeof(bih)));
+    if (AviReadStream* s = new AviReadStream(this, ash, 0, (char*)&bih, sizeof(bih)))
+	m_Streams.push_back(s);
 #endif
 
     for (;;)
@@ -360,10 +361,11 @@ uint_t AviReadHandler::GetStreamCount(IStream::StreamType type)
 void AviReadHandler::readInfoChunk(uint_t data_size)
 {
     uint_t rs = 0;
-    while (rs < data_size)
+    while (rs < data_size && !m_Input.eof())
     {
 	uint32_t type = m_Input.readDword();
 	uint32_t size = m_Input.readDword();
+	printf("rs r:%d ds:%d   t:%d  s:%d\n", rs, data_size, type, size);
 
 	if ((rs + size) < data_size)
 	{
@@ -378,6 +380,7 @@ void AviReadHandler::readInfoChunk(uint_t data_size)
 		    break;
 		}
 	}
+        printf("addd %d  %d\n", rs, size);
 	rs += size;
     }
 }
@@ -437,20 +440,29 @@ int AviReadHandler::readAVIStreamHeader()
     data_size += (data_size & 1);
 
     char* format = new char[data_size];
+    if (!format)
+        return -1;
     m_Input.read(format, data_size);
 
-    if (ash.fccType == streamtypeVIDEO)
+    if (ash.fccType == streamtypeVIDEO || ash.fccType == streamtypeIAVS)
     {
 	const uint_t bihs = sizeof(BITMAPINFOHEADER);
         BITMAPINFOHEADER* bih = (BITMAPINFOHEADER*) format;
 	if (data_size < bihs)
 	{
-	    char *t = new char[bihs];
-	    memset(t, 0, bihs);
-	    memcpy(t, format, data_size);
-	    delete[] format;
-	    format = t;
-            fsize = data_size = bihs;
+	    if (char* t = new char[bihs])
+	    {
+		memset(t, 0, bihs);
+		memcpy(t, format, data_size);
+		delete[] format;
+		format = t;
+		fsize = data_size = bihs;
+	    }
+	    else
+	    {
+		delete[] format;
+                return -1;
+	    }
 	}
 
 	avm_get_leBITMAPINFOHEADER(bih);
@@ -468,12 +480,19 @@ int AviReadHandler::readAVIStreamHeader()
 	uint_t wfs = sizeof(WAVEFORMATEX) + ((WAVEFORMATEX*)format)->cbSize;
 	if (data_size < wfs)
 	{
-	    char *t = new char[wfs];
-	    memcpy(t, format, data_size);
-	    memset(t + data_size, 0, wfs - data_size);
-	    delete[] format;
-	    format = t;
-	    fsize = data_size = wfs;
+	    if (char *t = new char[wfs])
+	    {
+		memcpy(t, format, data_size);
+		memset(t + data_size, 0, wfs - data_size);
+		delete[] format;
+		format = t;
+		fsize = data_size = wfs;
+	    }
+	    else
+	    {
+		delete[] format;
+                return -1;
+	    }
 	}
         avm_get_leWAVEFORMATEX((WAVEFORMATEX*) format);
 	if (!ash.dwSampleSize && ash.dwLength > 800000)
@@ -495,7 +514,8 @@ int AviReadHandler::readAVIStreamHeader()
 
     uint_t id = m_Streams.size();
     PrintAVIStreamHeader(&ash);
-    m_Streams.push_back(new AviReadStream(this, ash, id, format, fsize));
+    if (AviReadStream* s = new AviReadStream(this, ash, id, format, fsize))
+	m_Streams.push_back(s);
     delete[] format;
     return 0;
 }
@@ -507,7 +527,7 @@ int AviReadHandler::readIndexChunk(uint_t index_size, uint_t movie_chunk_offset)
     //for (unsigned i = 0; i < m_Streams.size(); i++)
     //    positions[i] = m_Streams[i]->m_Header.dwStart;
 
-    AVM_WRITE("AVI reader", "Reading index from offset: %d\n", m_Input.pos());
+    AVM_WRITE("AVI reader", "Reading index from offset: %lld\n", m_Input.pos());
 
     for (unsigned ip = 0; ip <= (index_size/sizeof(AVIINDEXENTRY))
 	 && !m_Input.eof(); ip++)
@@ -525,7 +545,7 @@ int AviReadHandler::readIndexChunk(uint_t index_size, uint_t movie_chunk_offset)
 	//printf ("Id  %u    off: %u   len:%u\n", ip, entry.dwChunkOffset, entry.dwChunkLength);
 	if (clen > StreamPacket::MAX_PACKET_SIZE)
 	{
-	    AVM_WRITE("AVI reader", "WARNING: invalid index entry %u -- id: %u  offset: %u size:  %u (pos: %u)\n",
+	    AVM_WRITE("AVI reader", "WARNING: invalid index entry %u -- id: %u  offset: %u size:  %u (pos: %lld)\n",
 		      ip, ckid, coffset, clen, m_Input.pos());
 	    return reconstructIndexChunk(stream->m_Offsets.back() & ~1);
 	}
@@ -549,7 +569,7 @@ int AviReadHandler::reconstructIndexChunk(uint_t offset)
     int64_t positions[m_Streams.size()];
     int isdivx[m_Streams.size()];
 
-    AVM_WRITE("AVI reader", "Reconstructing index from offset: %d\n", offset);
+    AVM_WRITE("AVI reader", "Reconstructing index from offset: %d s=%d\n", offset, m_Streams.size());
     // fixing KeyFrames for DivX movies by checking flag bit
     for (unsigned i = 0; i < m_Streams.size(); i++)
     {
@@ -597,43 +617,44 @@ int AviReadHandler::reconstructIndexChunk(uint_t offset)
     while (!m_Input.eof())
     {
 	uint_t ckid = m_Input.readDword();
+
+	if (ckid == ckidAVINEWINDEX)
+	    break;
+	//if (!ckid) continue;
 	uint_t id = StreamFromFOURCC(ckid);
 	//uint_t ckidt = TWOCCFromFOURCC(ckid);
 
-	if (ckid == ckidAVINEWINDEX)
-            break;
-
-	//printf("pos: %llu   %u   %u    %.4s\n", m_Input.pos(), id, m_Streams.size(), (char*)&ckid);
+	//printf("pos: %llu   %u   %u   %x  %d\n", m_Input.pos(), id, m_Streams.size(), ckid, seriouslyBroken);
 	if (id >= m_Streams.size())
 	{
-	    //printf("index type  0x%x   0x%x", (ckid & 0xffff), cktypeINDEX);
+	    //printf("index type  id:%d  ss:%d  0x%x   0x%x    ckid:0x%x\n", id, m_Streams.size(), (ckid & 0xffff), cktypeINDEX, ckid);
 	    if ((ckid & 0xffff) == cktypeINDEX)
 	    {
                 // skip indexes
 		uint32_t size = m_Input.readDword();
-		//printf("SKEEEEEP %d\n", size);
-		m_Input.seekCur(size);
+		//printf("SKEEEEEP %u\n", size);
+		if (size < ((seriouslyBroken) ? MAX_CHUNK_SIZE : 0xfffffffU))
+		    m_Input.seekCur(size);
 		continue;
 	    }
 
-	    if (m_Input.eof())
-		break;
-	    m_Input.seekCur(-2);
-            if (!seriouslyBroken)
+	    if (ckid && !m_Input.eof())
+		m_Input.seekCur(-2);
+	    if (!seriouslyBroken) {
 		AVM_WRITE("AVI reader", "Trying to reconstruct broken avi stream (could take a lot of time)\n");
-	    seriouslyBroken = true;
+		seriouslyBroken = true;
+	    }
 	    continue;
 	}
 
-	AviReadStream* stream = m_Streams[id];
-	uint_t coffset = m_Input.pos() - 4;
 	uint_t clen = m_Input.readDword();
 	if (clen > ((seriouslyBroken) ? MAX_CHUNK_SIZE : 0xfffffffU))
 	    continue;
 
-	//printf ("Id  %u    ps: %d  len:%u   0x%x\n", id, coffset, clen, ckid);
+	uint_t coffset = m_Input.pos() - 4 - 4; // two Dword readed
 
-	uint_t size = clen + (clen & 1); // round
+
+	uint_t size = (clen + 1) & ~1; // round
 	bool keyframe = (size > 0);
 
 	if (isdivx[id] && size)
@@ -673,11 +694,11 @@ int AviReadHandler::reconstructIndexChunk(uint_t offset)
 	    }
 	    size -= 4;
 	}
-
+	//printf("SEEK %d\n", size);
 	m_Input.seekCur(size);
 	if (m_Input.pos() > int64_t(coffset + size))
 	    // do not insert incomplete chunks
-	    stream->addChunk(coffset, clen, keyframe);
+	    m_Streams[id]->addChunk(coffset, clen, keyframe);
     }
 
     return 0;
@@ -719,8 +740,8 @@ void AviReadHandler::PrintAVIStreamHeader(const AVIStreamHeader* h)
 {
     char buffer[200];
 
-    char sb[10];
-    if (h->fccType == streamtypeVIDEO)
+    char sb[20];
+    if (h->fccType == streamtypeVIDEO || h->fccType == streamtypeIAVS)
     {
 	avm_set_le32(sb, h->fccHandler);
 	sb[4] = 0;
@@ -759,7 +780,7 @@ char* AviReadHandler::GetAviFlags(char* buffer, uint_t flags)
 IMediaReadHandler* CreateAviReadHandler(const char *pszFile, unsigned int flags)
 {
     AviReadHandler* r = new AviReadHandler(flags);
-    if (r->init(pszFile) == 0)
+    if (r && r->init(pszFile) == 0)
 	return r;
 
     delete r;
