@@ -13,32 +13,16 @@ IReadFile::~IReadFile() {}
 class ReadFile: public IReadFile
 {
     IMediaReadHandler* m_pHandler;
+    const char* m_Name;
+    uint_t m_Flags;
     avm::vector<ReadStream*> m_vstreams;
     avm::vector<ReadStream*> m_astreams;
 public:
-    ReadFile(const char* name, unsigned int flags) : m_pHandler(0)
+    ReadFile(const char* name, unsigned int flags)
+	: m_pHandler(0), m_Name(name), m_Flags(flags)
     {
-	if (!name || !strlen(name))
-	    return;
-
-	AVM_WRITE("reader", "Checking: %s\n", name);
-	const char* ff = getenv("AVIPLAY_FFMPEG");
-	if (ff)
-	    m_pHandler = CreateFFReadHandler(name);
-
-	if (!m_pHandler && !strstr(name, "://"))
-	    m_pHandler = CreateAviReadHandler(name, flags);
-
-	if (!m_pHandler)
-	    m_pHandler = CreateAsfReadHandler(name);
-
-	if (!m_pHandler && !ff)
-	    m_pHandler = CreateFFReadHandler(name);
-
-	if (!m_pHandler)
-	    AVM_WRITE("reader", "Can't open stream\n");//never get here
     }
-    ~ReadFile()
+    virtual ~ReadFile()
     {
 	for (unsigned i = 0; i < m_vstreams.size(); i++)
 	    delete m_vstreams[i];
@@ -48,6 +32,27 @@ public:
 
 	delete m_pHandler;
     }
+    int init()
+    {
+	if (m_Name)
+	{
+	    AVM_WRITE("reader", "Checking: %s\n", m_Name);
+	    const char* ff = getenv("AVIPLAY_FFMPEG");
+	    if (ff)
+		m_pHandler = CreateFFReadHandler(m_Name);
+
+	    if (!m_pHandler && !strstr(m_Name, "://"))
+		m_pHandler = CreateAviReadHandler(m_Name, m_Flags);
+
+	    if (!m_pHandler)
+		m_pHandler = CreateAsfReadHandler(m_Name);
+
+	    if (!m_pHandler && !ff)
+		m_pHandler = CreateFFReadHandler(m_Name);
+	}
+
+	return (m_pHandler) ? 0 : -1;
+    }
     virtual uint_t StreamCount()
     {
 	return VideoStreamCount() + AudioStreamCount();
@@ -89,10 +94,10 @@ public:
 	    {
 		if (!m_astreams[id])
 		{
-		    IMediaReadStream* r = m_pHandler->GetStream(id, type);
-		    if (!r)
+		    IMediaReadStream* s = m_pHandler->GetStream(id, type);
+		    if (!s || s->GetLength() > 0x7fffffff)
                         return 0;
-		    m_astreams[id] = new ReadStreamA(r);
+		    m_astreams[id] = new ReadStreamA(s);
 		}
                 return m_astreams[id];
 	    }
@@ -102,10 +107,10 @@ public:
 	    {
 		if (!m_vstreams[id])
 		{
-		    IMediaReadStream* r = m_pHandler->GetStream(id, type);
-		    if (!r)
-                        return 0;
-		    m_vstreams[id] = new ReadStreamV(r);
+		    IMediaReadStream* s = m_pHandler->GetStream(id, type);
+		    if (!s || s->GetLength() > 0x7fffffff)
+			return 0;
+		    m_vstreams[id] = new ReadStreamV(s);
 		}
                 return m_vstreams[id];
 	    }
@@ -128,7 +133,11 @@ public:
 IReadFile* CreateReadFile(const char* name, unsigned int flags)
 {
     ReadFile* r = new ReadFile(name, flags);
-    return r;
+    if (r && r->init() == 0)
+	return r;
+    AVM_WRITE("reader", "Can't open stream\n");
+    delete r;
+    return 0;
 }
 
 AVM_END_NAMESPACE;
