@@ -92,21 +92,20 @@ bits name              comments
 Mp3AudioInfo::Mp3AudioInfo() : frame_size(0) {}
 
 // MP3 header needs 40 bytes
-int Mp3AudioInfo::Init(const char* buf, int fast)
+inline int Mp3AudioInfo::Init(const char* buf, int fast)
 {
     header = avm_get_be32(buf);
-
     //AVM_WRITE("audio reader", "HDR %x    %.4s\n", header, (char*)&header);
     // CHECK if it's mpeg & Get the sampling frequency
-    int frequency_index = (header >> 10) & 3; // MPEG_FREQUENCY_MASK
-    layer = 4 - (header >> 17) & 3;
-    mode = (MPEG_MODE) (3 - (header >> 19) & 3); // MPEG_ID_MASK
+
+    int frequency_index;
     if ((header & 0xffe00000) != 0xffe00000
-	|| frequency_index > 2 || layer > 3 || mode == 2)
-	return 0; // this is not mpeg header
-
-    sample_rate = mpeg_sample_rates[mode][frequency_index];
+	|| ((layer = 4 - ((header & MPEG_LAYER_MASK) >> 17)) > 3)
+	|| ((mode = (MPEG_MODE) (3 - (header >> 19) & 3)) == Mp3AudioInfo::ERR) // MPEG_ID_MASK
+	|| ((frequency_index = (header & MPEG_FREQUENCY_MASK)) == MPEG_FREQUENCY_MASK))
+	return 0; // not mp3 header
 
+    sample_rate = mpeg_sample_rates[mode][frequency_index >> 10];
     //AVM_WRITE("audio reader", "HDR %x    m:%d  fi:%d   sr:%d\n", header, mode, frequency_index, sample_rate);
     // Get stereo mode index
     stereo_mode = (STEREO_MODE)((header & MPEG_MODE_MASK) >> 6);
@@ -141,13 +140,13 @@ int Mp3AudioInfo::Init(const char* buf, int fast)
 
     return start_offset;
 }
-int Mp3AudioInfo::GetBitrate()
+int Mp3AudioInfo::GetBitrate() const
 {
     int bitrate_idx = (header & MPEG_BITRATE_MASK) >> 12;
     int layer_idx = layer + ((layer > 0 && mode == MPEG1) ? -1 : 2);
     return mpeg_bitrates[layer_idx][bitrate_idx] * 1000;
 }
-int Mp3AudioInfo::GetFrameSize()
+int Mp3AudioInfo::GetFrameSize() const
 {
     int tmp_bitrate = GetBitrate();
 
@@ -166,10 +165,10 @@ int Mp3AudioInfo::GetFrameSize()
 
     return ret;
 }
-void Mp3AudioInfo::PrintHeader()
+void Mp3AudioInfo::PrintHeader() const
 {
-    const char* sf[] = { "MPEG1", "MPEG2", "ERR", "MPEG2.5" };
-    const char* sm[] = { "Stereo", "JointStereo", "DualChannel", "Mono" };
+    static const char* sf[] = { "MPEG1", "MPEG2", "ERR", "MPEG2.5" };
+    static const char* sm[] = { "Stereo", "JointStereo", "DualChannel", "Mono" };
     if (frame_size)
 	AVM_WRITE("audio reader", "%s Layer-%d %dHz %dkbps %s %s"
 		  "(%d,%d,%d)\n",
@@ -179,7 +178,7 @@ void Mp3AudioInfo::PrintHeader()
 }
 
 ReadStreamA::ReadStreamA(IMediaReadStream* stream)
-    :ReadStream(stream), m_pAudiodecoder(0), m_uiMinSize(0), m_bIsMp3(false)
+    : ReadStream(stream), m_pAudiodecoder(0), m_uiMinSize(0), m_bIsMp3(false)
 {
     // FIXME - asf reading needs to know also about VideoStreams
     // currently this isn't possible to use it this way
@@ -187,24 +186,29 @@ ReadStreamA::ReadStreamA(IMediaReadStream* stream)
     WAVEFORMATEX* wf = (WAVEFORMATEX*) m_pFormat;
 
     // fix incorrect header
-    if (wf->wFormatTag == 0x55 && (wf->cbSize != 12
-				   || m_uiFormatSize < sizeof(MP3WAVEFORMATEX)))
+    if (wf->wFormatTag == 0x55
+	&& (wf->cbSize != 12
+	    || m_uiFormatSize < sizeof(MP3WAVEFORMATEX)))
     {
 	if (m_uiFormatSize < sizeof(MP3WAVEFORMATEX))
 	    AVM_WRITE("audio reader", "WARNING: fixing bad WAVEFORMAT header for MP3 audio track (sz:%d != %d)\n", m_uiFormatSize, sizeof(MP3WAVEFORMATEX));
         else
 	    AVM_WRITE("audio reader", "WARNING: fixing bad WAVEFORMAT header for MP3 audio track (cb:%d != 12)\n", wf->cbSize);
 	m_uiFormatSize = sizeof(MP3WAVEFORMATEX);
-	m_pFormat = new char[m_uiFormatSize];
-	memcpy(m_pFormat, wf, sizeof(WAVEFORMATEX));
-	delete[] wf;
-        wf = (WAVEFORMATEX*) m_pFormat;
+	if ((m_pFormat = new char[m_uiFormatSize]))
+	{
+	    memcpy(m_pFormat, wf, sizeof(WAVEFORMATEX));
+	    delete[] wf;
+	    wf = (WAVEFORMATEX*) m_pFormat;
+	}
+	else
+	    m_pFormat = (char*) wf;
 	MP3WAVEFORMATEX* mwf = (MP3WAVEFORMATEX*) m_pFormat;
 
 	mwf->wf.cbSize = sizeof(MP3WAVEFORMATEX) - sizeof(WAVEFORMATEX);//12
 	mwf->wID = 1;			//
 	mwf->fdwFlags = 2;		// These values based on an old Usenet post!!
-	mwf->nBlockSize = 0;		// this value COMPUTE later...
+	mwf->nBlockSize = 0;		// evaluate this value later...
 	mwf->nFramesPerBlock = 1;	//
 	mwf->nCodecDelay = 1393;	// 0x571 for F-IIS MP3 Codec
     }
@@ -227,15 +231,15 @@ ReadStreamA::ReadStreamA(IMediaReadStream* stream)
 	    {
 		if (bf)
 		{
-		    memcpy(b, b + 1, bf);
+		    memmove(b, b + 1, bf);
 		    bf--; // next byte
 		}
 		uint_t samp, bytes = 4 - bf;
-                //printf("BYTES %d %d %d\n", bytes, bf, samp);
+		printf("BYTES %d %d\n", bytes, bf);
 		if (ReadDirect(b + bf, bytes, bytes, samp, bytes) < 0)
 		    //|| !bytes)
 		    break;
-		//printf("READ %d  %d\n", bytes, samp);
+		printf("Mp3Header READ %d  %d\n", bytes, samp);
 		bf += bytes;
                 rb += bytes;
 		//printf("RB %d  %d   0x%x\n", rb, bytes, *(int*)b);
@@ -370,6 +374,8 @@ ReadStreamA::ReadStreamA(IMediaReadStream* stream)
 	    wf->nSamplesPerSec = 48000;
 	break;
     }
+
+    //printf("AFTERCONST pos: %d  l:%d  s:%d\n", m_uiLastPos, rem_local, rem_size);
 }
 
 ReadStreamA::~ReadStreamA()
@@ -412,33 +418,32 @@ uint_t ReadStreamA::GetOutputFormat(void* format, uint_t size) const
 
 framepos_t ReadStreamA::GetPos() const
 {
+    //printf("READA %d\n", m_uiSampleSize);
     if (m_uiSampleSize)
     {
-	uint_t sub = rem_size / m_uiSampleSize;
-	if (sub > m_uiLastPos)
-	    sub = m_uiLastPos;
-        m_uiLastPos - sub;
+	//printf("READAAAAA %d   %d    %d\n", m_uiLastPos, rem_size);
+	return (rem_size < m_uiLastPos) ? m_uiLastPos - rem_size : 0;
     }
     return m_uiLastPos;
 }
 
 double ReadStreamA::GetTime(framepos_t pos) const
 {
-    //printf("GETTIMA %f  %d  %d\n", m_dLastTime, rem_size, pos);
-    //AVM_WRITE("audio reader", "GETTIME   %d   %f   %d\n", pos, smtime, rem_size);
+    //AVM_WRITE("audio reader", "AGetTime: %d   last:%f   rem_size:%d   bps:%d\n", pos, m_dLastTime, rem_size, m_uiBps);
     //printf("ret %f   %f\n", smtime, rem_size/(double)dwBps);
     if (pos == ERR)
     {
 	double smtime = m_dLastTime;
 	if (m_uiBps > 0)
 	{
-	    //AVM_WRITE("audio reader", "AudioGetTime remsize %f   time: %f  pos: %d\n", rem_size/(double)dwBps, smtime, pos);
-	    // rem_size must be kept small otherwice
+	    //AVM_WRITE("audio reader", "AudioGetTime remsize %f   time: %f  pos: %d\n", rem_size/(double)m_uiBps, smtime, pos);
+	    // rem_size must be kept small otherwise
 	    // there will be sync problems with VBR audio
 	    smtime -= rem_size / (double)m_uiBps;
-	    if (smtime < 0.0)
-		smtime = 0.0;
+	    if (smtime < 0.)
+		smtime = 0.;
 	}
+	//printf("GETTIME ret=%f\n", smtime);
         return smtime;
     }
     return m_pStream->GetTime(pos);
@@ -457,24 +462,21 @@ int ReadStreamA::ReadFrames(void* buffer, uint_t bufsize, uint_t samples,
 
     uint_t srcsize = m_pAudiodecoder->GetSrcSize(bufsize);
     bool bHadPacket = false;
-    //printf("MIN  %d   SRC %d    reml:%d  rems:%d    bs:%d\n", m_uiMinSize, srcsize, rem_local, rem_size, bufsize);
+    //printf("***ReadFrames***  MIN  %d   SRC %d    reml:%d  rems:%d    bs:%d\n", m_uiMinSize, srcsize, rem_local, rem_size, bufsize);
     if (m_bIsMp3 && rem_size >= 4)
     {
         // for vbr audio keep buffer minimal for the good timing
 	Mp3AudioInfo ai;
 	if (ai.Init(rem_buffer + rem_local, false))
-	    srcsize = ai.frame_size * 2;
+	    srcsize = ai.frame_size;// * 2;
 	//printf("RESULT %d  %d\n", srcsize, ai.frame_size);
     }
 
     // wrap the buffer around
     if (rem_local > rem_limit/2)
     {
-	if (rem_size > 0)
-	{
-	    memcpy(rem_buffer, rem_buffer + rem_local, rem_size);
-	    //printf("MEMCPY %d\n", rem_size);
-	}
+	memcpy(rem_buffer, rem_buffer + rem_local, rem_size);
+	//printf("MEMCPY %d\n", rem_size);
         rem_local = 0;
     }
     while (rem_size <= srcsize)
@@ -489,12 +491,13 @@ int ReadStreamA::ReadFrames(void* buffer, uint_t bufsize, uint_t samples,
 	    uint_t ns = rem_local + rem_size + m_pPacket->size;
 	    if (ns < srcsize)
 		ns = srcsize;
-	    if (ns > 2 * rem_limit)
+	    if (ns > rem_limit * 2)
 	    {
 		rem_limit = (ns > 50000U) ? ns : 50000U;
 		char* temp_buffer = (char*)malloc(rem_limit * 2);
 		if (rem_buffer)
 		{
+                    // copy the rest of current buffer to new location
 		    memcpy(temp_buffer, rem_buffer + rem_local, rem_size);
 		    free(rem_buffer);
 		    rem_local = 0;
@@ -549,8 +552,15 @@ int ReadStreamA::ReadFrames(void* buffer, uint_t bufsize, uint_t samples,
 				      (char*)buffer, bufsize, &lr, &ocnt);
     //int ds = open("/tmp/xyz", O_WRONLY | O_CREAT | O_APPEND, 0666); write(ds, rem_buffer + rem_local, lr); close(ds);
     //int ws = open("/tmp/wav", O_WRONLY | O_CREAT | O_APPEND, 0666); write(ws, buffer, ocnt); close(ws);
-    //printf("CONVSZE %d  %d   %d  rs:%d   bs:%d\n", lr, ocnt, hr, rem_size, bufsize);
-    if (hr < 0 || (ocnt <= 0 && lr <= 0))
+    //printf("CONVSZE bytes:%d  samples:%d   r:%d  rem_size:%d/%d   bs:%d\n", lr, ocnt, hr, rem_size, srcsize, bufsize);
+    if (hr >= 0 && (ocnt > 0 || lr > 0))
+    {
+	if (lr > rem_size)
+	    lr = rem_size;
+	rem_local += lr;
+	rem_size -= lr;
+    }
+    else
     {
 	//printf("ERRORCONVSZE %d  %d   %d   rs: %d\n", lr, ocnt, hr, rem_size );
         uint_t bs = ((WAVEFORMATEX*)m_pFormat)->nBlockAlign;
@@ -563,13 +573,6 @@ int ReadStreamA::ReadFrames(void* buffer, uint_t bufsize, uint_t samples,
 	    rem_size = 0;
         ocnt = 0;
     }
-    else
-    {
-	if (lr > rem_size)
-	    lr = rem_size;
-	rem_local += lr;
-	rem_size -= lr;
-    }
 
     //AVM_WRITE("audio reader", "locread:%6d outputsz:%7d convsz:%6d lr:%d  bs:%d\n", rem_local, ocnt, convsz, lr, rem_size);
 #if 0
@@ -598,41 +601,36 @@ int ReadStreamA::ReadFrames(void* buffer, uint_t bufsize, uint_t samples,
 
 int ReadStreamA::SkipTo(double pos)
 {
-    //printf("SKIPPOS %f   %f  %d  bps:%d\n", pos, GetTime(), m_uiSampleSize, dwBps);
-    char* b = new char[8192];
-    int i = 0;
+    //printf("SKIPPOS %f   %f  %d  bps:%d\n", pos, GetTime(), m_uiSampleSize, m_uiBps);
     if (!m_uiSampleSize)
-        return 0;
+	return 0;
+    avm::vector<char> b(8192);
+    const unsigned max = b.size() / m_uiSampleSize;
     while ((pos - GetTime()) > 0.001)
     {
 	uint_t samples_read, bytes_read;
-	int bt;
+        unsigned m;
 	if (m_uiBps > 0)
 	{
-	    int m = (int)((pos - GetTime()) * m_uiBps) / (int) m_uiSampleSize;
-	    if (m > (int)(8192 / m_uiSampleSize))
-		m = (8192 / m_uiSampleSize);
+	    if ((m = unsigned((pos - GetTime()) * m_uiBps) / m_uiSampleSize) == 0)
+		break; // can't get any closer
 
-	    //printf("M %d  %d\n", m, m_uiSampleSize);
-	    if (m > 0)
-		bt = m * m_uiSampleSize; // rounded to sample size
-	    else
-		break;
-	}
-	else
-	    bt = 2 * m_uiSampleSize;
-	if (ReadDirect(b, bt, bt / m_uiSampleSize, samples_read, bytes_read) < 0
+	    if (m > max)
+		m = max;
+	} else
+	    m = 2;
+	//printf("Skip blocks %d  %d   t:%f\n", m, m_uiSampleSize, pos, GetTime());
+	if (ReadDirect(b.begin(), m * m_uiSampleSize, m, samples_read, bytes_read) < 0
 	    || !bytes_read)
 	    break;
     }
-    delete[] b;
     return 0;
 }
 
 int ReadStreamA::SeekTime(double timepos)
 {
     double t = GetTime();
-    if ((timepos - t) < 0.001 && (timepos - t) > -0.001 && timepos > 0.001)
+    if ((timepos - t) < 0.002 && (timepos - t) > -0.002 && timepos > 0.002)
     {
 	//printf("---------SEEK DISCARD %f  %f\n", t, timepos);
 	return 0;
@@ -655,7 +653,6 @@ int ReadStreamA::StartStreaming(const char* privname)
     }
 
     m_uiMinSize = m_pAudiodecoder->GetMinSize();
-    Flush();
     return 0;
 }
 
