@@ -9,7 +9,7 @@
 #include "configfile.h"
 #include "utils.h"
 #include "avm_output.h"
-
+#include "aviplay.h"    // GetAvifileVersion
 #include "version.h"
 
 #include "../plugins/libac3pass/fillplugins.h"
@@ -23,6 +23,7 @@
 #include "../plugins/libvorbis/fillplugins.h"
 #include "../plugins/libwin32/fillplugins.h"
 #include "../plugins/libxvid/fillplugins.h"
+#include "../plugins/libxvid4/fillplugins.h"
 #include "../samples/mjpeg_plugin/fillplugins.h"
 #include "Uncompressed.h"
 
@@ -56,13 +57,12 @@ static bool pluginit = false;
 const char* plugin_def_path = PLUGIN_PATH;
 static avm::string last_error;
 
-
 AVM_BEGIN_NAMESPACE;
 
 static avm::vector<CodecInfo*> video_order;
 static avm::vector<CodecInfo*> audio_order;
 
-#ifdef ARCH_X86
+#ifdef ARCH_X86_32
 /*
  * LDT_Keeper MUST be here
  * LDT must be modified before program creates first thread
@@ -85,7 +85,8 @@ struct LDT_Keeper
 	{
 	    ldt_fs = Setup_LDT_Keeper();
 	    if (ldt_fs)
-		AVM_WRITE("LDT keeper", "Installed fs segment: %p\n", ldt_fs->fs_seg);
+		AVM_WRITE("LDT keeper", "Installed fs segment: %p\n",
+			  ldt_fs->fs_seg);
 	}
     }
 };
@@ -95,10 +96,8 @@ static LDT_Keeper Keeper;
 
 static void plugin_close(const CodecInfo& ci)
 {
-    if (ci.handle)
+    if (PluginPrivate* pi = (PluginPrivate*) ci.handle)
     {
-	PluginPrivate* pi = (PluginPrivate*) ci.handle;
-
 	//printf("PLUGINCLOSE  %p   c:%d\n", pi, (pi)?pi->refcount:12345);
 	if (--pi->refcount <= 0 && pi->dlhandle)
 	{
@@ -117,15 +116,16 @@ static void plugin_close(const CodecInfo& ci)
 
 codec_plugin_t* plugin_open(const CodecInfo& ci)
 {
-    PluginPrivate* pi;
     const char* name = ci.modulename.c_str();
-    if (!ci.handle)
+    PluginPrivate* pi = (PluginPrivate*) ci.handle;
+    if (!pi)
     {
-	pi = new PluginPrivate;
+	pi = new PluginPrivate();
 	pi->dlhandle = dlopen(name, RTLD_LAZY | RTLD_PARENT);
 	if (!pi->dlhandle)
 	{
-	    AVM_WRITE("codec keeper", "WARNING: plugin %s could not be opened: %s\n",
+	    AVM_WRITE("codec keeper",
+		      "WARNING: plugin %s could not be opened: %s\n",
 		      name, dlerror());
 	    delete pi;
 	    return 0;
@@ -134,8 +134,6 @@ codec_plugin_t* plugin_open(const CodecInfo& ci)
         pi->refcount = 0;
 	ci.handle = pi;
     }
-    else
-        pi = (PluginPrivate*) ci.handle;
 
     pi->refcount++;
     if (!pi->fchandle)
@@ -151,10 +149,12 @@ codec_plugin_t* plugin_open(const CodecInfo& ci)
 	if (!plugin || (plugin->version != PLUGIN_API_VERSION))
 	{
             if (plugin)
-		AVM_WRITE("codec keeper", "WARNING: plugin %s has version %d, expected %d (should be removed)\n",
+		AVM_WRITE("codec keeper",
+			  "WARNING: plugin %s has version %d, expected %d (should be removed)\n",
 			  name, plugin->version, PLUGIN_API_VERSION);
 	    else
-		AVM_WRITE("codec keeper", "WARNING: plugin %s is in incompatible format\n",
+		AVM_WRITE("codec keeper",
+			  "WARNING: plugin %s is in incompatible format\n",
 			  name);
 	    plugin_close(ci);
 	    return 0;
@@ -164,7 +164,8 @@ codec_plugin_t* plugin_open(const CodecInfo& ci)
     return (codec_plugin_t*) pi->fchandle;
 }
 
-static void plugin_add_list(avm::vector<CodecInfo>& ci, const avm::string& fullname)
+static void plugin_add_list(avm::vector<CodecInfo>& ci,
+			    const avm::string& fullname)
 {
     int vp = 0;
     for (unsigned i = 0; i < ci.size(); i++)
@@ -340,12 +341,13 @@ static void plugin_fill()
 	    { "divx4", divx4_FillPlugins },
 	    { "ffmpeg", ffmpeg_FillPlugins },
 	    { "mad_audiodec", mad_FillPlugins },
-	    { "mjpeg", ijpg_FillPlugins },
 	    { "mp3lame_audioenc", mp3lame_FillPlugins },
 	    { "mp3lamebin_audioenc", mp3lamebin_FillPlugins },
 	    { "mpeg_audiodec", mpeg_audiodec_FillPlugins },
+	    { "osmjpeg", ijpg_FillPlugins },
 	    { "vorbis", vorbis_FillPlugins },
 	    { "win32", win32_FillPlugins },
+	    { "xvid4", xvid4_FillPlugins }, // MUST BE before standalone xvid!
 	    { "xvid", xvid_FillPlugins },
 	    { 0 }
 	};
@@ -354,15 +356,15 @@ static void plugin_fill()
 	 * This chunk of code eliminates the need to open several shared
 	 * libraries while starting every application
 	 */
-	const plugin_map* c = pm;
-	for (; c->name; c++)
+	const plugin_map* c;
+	for (c = pm; c->name; c++)
 	{
 	    if (dllname.substr(0, strlen(c->name)) == c->name)
 	    {
 		avm::vector<CodecInfo> ci;
 		c->fill(ci);
 		plugin_add_list(ci, fullname);
-#ifdef ARCH_X86
+#ifdef ARCH_X86_32
 		if (strcmp(c->name, "win32") == 0)
 		    Keeper.init();
 #endif
@@ -407,32 +409,35 @@ static void plugin_fill()
 
     // move just numbers...
     video_order.resize(video_codecs.size());
-    for (uint_t v = 0; v < video_order.size(); v++) video_order[v] = &video_codecs[v];
+    for (unsigned v = 0; v < video_order.size(); v++)
+	video_order[v] = &video_codecs[v];
     audio_order.resize(audio_codecs.size());
-    for (uint_t a = 0; a < audio_order.size(); a++) audio_order[a] = &audio_codecs[a];
+    for (unsigned a = 0; a < audio_order.size(); a++)
+	audio_order[a] = &audio_codecs[a];
 
     // use by default - but each codec might use it's own order
-    sol = RegReadString("aviplay", "codecs_video", "ff");
+    sol = RegReadString("aviplay", "codecs-video", "ff");
     sort_codec_list(video_order, sol.c_str());
 
-    sol = RegReadString("aviplay", "codecs_audio", "ff");
+    sol = RegReadString("aviplay", "codecs-audio", "ff");
     sort_codec_list(audio_order, sol.c_str());
 }
 
-
-avm::string CodecGetError()
+const avm::string& CodecGetError()
 {
     return last_error;
 }
 
-void CodecInfo::Get(avm::vector<const CodecInfo*>& infos, CodecInfo::Media media,
+void CodecInfo::Get(avm::vector<const CodecInfo*>& infos,
+		    CodecInfo::Media media,
 		    Direction dir, fourcc_t fcc)
 {
     plugin_fill();
-    avm::vector<CodecInfo*>& v = (media == Video) ? video_order : audio_order;
+    const avm::vector<CodecInfo*>& v = (media == Video)
+	? video_order : audio_order;
 
     //infos.clear(); // ??? unsure
-    for (uint_t i = 0; i < v.size(); i++)
+    for (unsigned i = 0; i < v.size(); i++)
     {
 	if (v[i]->direction != Both
 	    && dir != Both
@@ -452,22 +457,22 @@ void CodecInfo::Get(avm::vector<const CodecInfo*>& infos, CodecInfo::Media media
 }
 
 
-IVideoDecoder* CreateDecoderVideo(const BITMAPINFOHEADER& bh, int depth, int flip, const char* privcname)
+IVideoDecoder* CreateDecoderVideo(const BITMAPINFOHEADER& bh, int depth,
+				  int flip, const char* privcname)
 {
     plugin_fill();
     if (bh.biCompression == 0xffffffff)
         return 0;
 
-    avm::vector<CodecInfo*>::iterator it;
-    for (it = video_order.begin(); it != video_order.end(); it++)
+    avm::vector<CodecInfo*>::const_iterator it;
+    for (it = video_order.begin(); it != video_order.end(); ++it)
     {
-	CodecInfo& ci = *(*it);
-	if (!(ci.direction & CodecInfo::Decode))
+	const CodecInfo& ci = *(*it);
+	if (!(ci.direction & CodecInfo::Decode)
+	    || (privcname && strcmp(ci.GetPrivateName(), privcname) != 0))
 	    continue;
-	if (privcname && (ci.privatename != privcname))
-	    continue;
-	avm::vector<fourcc_t>::const_iterator iv = ci.fourcc_array.begin();
-	for (; iv != ci.fourcc_array.end(); iv++)
+	avm::vector<fourcc_t>::const_iterator iv;
+	for (iv = ci.fourcc_array.begin(); iv != ci.fourcc_array.end(); ++iv)
 	{
 	    if (bh.biCompression == *iv)
 	    {
@@ -487,7 +492,8 @@ IVideoDecoder* CreateDecoderVideo(const BITMAPINFOHEADER& bh, int depth, int fli
 			{
 			    // try again with default codec for this
 			    // fourcc array
-			    AVM_WRITE("codec keeper", "Trying to use %.4s instead of %.4s\n",
+			    AVM_WRITE("codec keeper",
+				      "Trying to use %.4s instead of %.4s\n",
 				      (const char*)&ci.fourcc,
 				      (const char*)&bh.biCompression);
 			    BITMAPINFOHEADER dbh(bh);
@@ -498,7 +504,9 @@ IVideoDecoder* CreateDecoderVideo(const BITMAPINFOHEADER& bh, int depth, int fli
 			if (vd)
 			{
 			    //it->handle = handle;
-			    AVM_WRITE("codec keeper", "%s video decoder created\n", ci.GetName());
+			    AVM_WRITE("codec keeper",
+				      "Created video decoder: %s\n",
+				      ci.GetName());
 			    return vd;
 			}
 			plugin_get_error(plugin);
@@ -510,20 +518,18 @@ IVideoDecoder* CreateDecoderVideo(const BITMAPINFOHEADER& bh, int depth, int fli
     }//for
 
     char s[5];
-    char err[100];
-    sprintf(err, "Unknown codec 0x%x = \"%.4s\"", bh.biCompression,
-	    avm_set_le32(s, bh.biCompression));
-    last_error = err;
-    AVM_WRITE("codec keeper", "CreateVideoDecoder(): %s\n", err);
+    last_error.sprintf("Unknown codec 0x%x = \"%.4s\"", bh.biCompression,
+		       avm_set_le32(s, bh.biCompression));
+    AVM_WRITE("codec keeper", "CreateVideoDecoder(): %s\n", last_error.c_str());
     return 0;
 }
 
-IVideoEncoder* CreateEncoderVideo(const CodecInfo& ci, const BITMAPINFOHEADER& bh)
+IVideoEncoder* CreateEncoderVideo(const CodecInfo& ci,
+				  const BITMAPINFOHEADER& bh)
 {
     if (!(ci.direction & CodecInfo::Encode))
 	return 0;
-    uint_t index = video_codecs.find(ci);
-    if (index == avm::vector<CodecInfo>::invalid)
+    if (video_codecs.find(ci) == avm::vector<CodecInfo>::invalid)
     {
 	AVM_WRITE("codec keeper", "Failed to find this CodecInfo in list\n");
 	return 0;
@@ -554,59 +560,47 @@ IVideoEncoder* CreateEncoderVideo(const CodecInfo& ci, const BITMAPINFOHEADER& b
     return 0;
 }
 
-IVideoEncoder* CreateEncoderVideo(fourcc_t compressor, const BITMAPINFOHEADER& bh, const char* cname)
+IVideoEncoder* CreateEncoderVideo(fourcc_t compressor,
+				  const BITMAPINFOHEADER& bh, const char* cname)
 {
     plugin_fill();
 
-    avm::vector<CodecInfo*>::iterator it;
-    for (it = video_order.begin(); it != video_order.end(); it++)
+    avm::vector<CodecInfo*>::const_iterator it;
+    for (it = video_order.begin(); it != video_order.end(); ++it)
     {
-        CodecInfo& ci = *(*it);
+        const CodecInfo& ci = *(*it);
 	if (!(ci.direction & CodecInfo::Encode)
-	    || (cname && strcmp(ci.GetName(), cname)))
+	    || (cname && strcmp(ci.GetName(), cname) != 0))
 	    continue;
 	//AVM_WRITE("codec keeper", 0, "Check dir:%d  0x%x (%.4s)   cname:(%s)\n", ci.direction,
 	//	  compressor, (const char*) &compressor, cname);
 	if ((cname && !compressor) || ci.fourcc == compressor)
-	{
-    	    IVideoEncoder* ve = CreateEncoderVideo(ci, bh);
-	    if(ve)
+	    if (IVideoEncoder* ve = CreateEncoderVideo(ci, bh))
 	    {
-		AVM_WRITE("codec keeper", "%s video encoder created\n", ci.GetName());
+		AVM_WRITE("codec keeper", "%s video encoder created\n",
+			  ci.GetName());
 	        return ve;
 	    }
-	}
     }
 
     char s[5];
-    char err[100];
-    sprintf(err, "Unknown codec 0x%x = \"%.4s\"", compressor,
-	    avm_set_le32(s, compressor));
-    last_error = err;
-    AVM_WRITE("codec keeper", "CreateVideoEncoder(): %s\n", err);
+    last_error.sprintf("Unknown codec 0x%x = \"%.4s\"", compressor,
+		       avm_set_le32(s, compressor));
+    AVM_WRITE("codec keeper", "CreateVideoEncoder(): %s\n", last_error.c_str());
     return 0;
 }
 
 IVideoEncoder* CreateEncoderVideo(const VideoEncoderInfo& info)
 {
-    const char* cname = info.cname.c_str();
-    if (strlen(cname) == 0)
-        cname = 0;
-    IVideoEncoder* ve = CreateEncoderVideo(info.compressor, info.header, cname);
-    if (ve)
-    {
-	ve->SetQuality(info.quality);
-	ve->SetKeyFrame(info.keyfreq);
-    }
-    return ve;
+    const char* cname = info.cname.size() ? info.cname.c_str() : 0;
+    return CreateEncoderVideo(info.compressor, info.header, cname);
 }
 
 IAudioEncoder* CreateEncoderAudio(const CodecInfo& ci, const WAVEFORMATEX* fmt)
 {
     if (!(ci.direction & CodecInfo::Encode))
 	return 0;
-    uint_t index = audio_codecs.find(ci);
-    if (index == avm::vector<CodecInfo>::invalid)
+    if (audio_codecs.find(ci) == avm::vector<CodecInfo>::invalid)
     {
 	AVM_WRITE("codec keeper", "Failed to find this CodecInfo in list\n");
 	return 0;
@@ -615,8 +609,7 @@ IAudioEncoder* CreateEncoderAudio(const CodecInfo& ci, const WAVEFORMATEX* fmt)
     codec_plugin_t* plugin = plugin_open(ci);
     if (plugin && plugin->audio_encoder)
     {
-	IAudioEncoder* ae = plugin->audio_encoder(ci, ci.fourcc, fmt);
-	if (ae)
+	if (IAudioEncoder* ae = plugin->audio_encoder(ci, ci.fourcc, fmt))
 	    return ae;
 	plugin_get_error(plugin);
     }
@@ -625,44 +618,39 @@ IAudioEncoder* CreateEncoderAudio(const CodecInfo& ci, const WAVEFORMATEX* fmt)
     return 0;
 }
 
-IAudioEncoder* CreateEncoderAudio(fourcc_t compressor, const WAVEFORMATEX* format)
+IAudioEncoder* CreateEncoderAudio(fourcc_t compressor,
+				  const WAVEFORMATEX* format)
 {
     plugin_fill();
 
-    avm::vector<CodecInfo*>::iterator it;
-    for (it = audio_order.begin(); it != audio_order.end(); it++)
+    avm::vector<CodecInfo*>::const_iterator it;
+    for (it = audio_order.begin(); it != audio_order.end(); ++it)
     {
-	CodecInfo& ci = *(*it);
-	if (!(ci.direction & CodecInfo::Encode))
-	    continue;
-	if(ci.fourcc_array.find(compressor) != avm::vector<fourcc_t>::invalid)
-	{
-	    IAudioEncoder* ae = CreateEncoderAudio(ci, format);
-	    if(ae)
-	        return ae;
-	}
+	const CodecInfo& ci = *(*it);
+	if ((ci.direction & CodecInfo::Encode)
+	    && ci.fourcc_array.find(compressor) != avm::vector<fourcc_t>::invalid)
+	    if (IAudioEncoder* ae = CreateEncoderAudio(ci, format))
+                return ae;
     }
-    char err[100];
-    sprintf(err, "No audio decoder for ID 0x%x", format->wFormatTag);
-    last_error = err;
+    last_error.sprintf("No audio decoder for ID 0x%x", format->wFormatTag);
     return 0;
 }
 
-IAudioDecoder* CreateDecoderAudio(const WAVEFORMATEX* format, const char* privcname)
+IAudioDecoder* CreateDecoderAudio(const WAVEFORMATEX* format,
+				  const char* privcname)
 {
     plugin_fill();
 
-    avm::vector<CodecInfo*>::iterator it;
-    for (it = audio_order.begin(); it != audio_order.end(); it++)
+    avm::vector<CodecInfo*>::const_iterator it;
+    for (it = audio_order.begin(); it != audio_order.end(); ++it)
     {
-        CodecInfo& ci = *(*it);
-	if (!(ci.direction & CodecInfo::Decode))
-	    continue;
-	if (privcname && (ci.privatename != privcname))
+        const CodecInfo& ci = *(*it);
+	if (!(ci.direction & CodecInfo::Decode)
+	    || (privcname && strcmp(ci.GetPrivateName(), privcname) != 0))
 	    continue;
 
 	avm::vector<fourcc_t>::const_iterator iv;
-	for (iv = ci.fourcc_array.begin(); iv != ci.fourcc_array.end(); iv++)
+	for (iv = ci.fourcc_array.begin(); iv != ci.fourcc_array.end(); ++iv)
 	{
 	    //printf("Audio search %x  for %x\n", format->wFormatTag, *iv);
 	    if (unsigned(format->wFormatTag) == *iv)
@@ -686,7 +674,9 @@ IAudioDecoder* CreateDecoderAudio(const WAVEFORMATEX* format, const char* privcn
 			if (ad)
 			{
 			    //ci.handle = handle;
-			    AVM_WRITE("codec keeper", "%s audio decoder created\n", ci.GetName());
+			    AVM_WRITE("codec keeper",
+				      "%s audio decoder created\n",
+				      ci.GetName());
 			    return ad;
 			}
 
@@ -699,9 +689,7 @@ IAudioDecoder* CreateDecoderAudio(const WAVEFORMATEX* format, const char* privcn
 	}
     }
 
-    char err[100];
-    sprintf(err, "No audio decoder for ID 0x%x", format->wFormatTag);
-    last_error = err;
+    last_error.sprintf("No audio decoder for ID 0x%x", format->wFormatTag);
     return 0;
 }
 
@@ -753,7 +741,8 @@ int CodecSetAttr(const CodecInfo& info, const char* attribute, int value)
     return result;
 }
 
-int CodecGetAttr(const CodecInfo& info, const char* attribute, const char** value)
+int CodecGetAttr(const CodecInfo& info, const char* attribute,
+		 const char** value)
 {
     int result = -1;
     codec_plugin_t* plugin = plugin_open(info);
@@ -765,7 +754,8 @@ int CodecGetAttr(const CodecInfo& info, const char* attribute, const char** valu
     return result;
 }
 
-int CodecSetAttr(const CodecInfo& info, const char* attribute, const char* value)
+int CodecSetAttr(const CodecInfo& info, const char* attribute,
+		 const char* value)
 {
     int result = -1;
     codec_plugin_t* plugin = plugin_open(info);
@@ -829,24 +819,25 @@ int SortAudioCodecs(const char* orderlist)
     return sort_codec_list(audio_order, orderlist);
 }
 
-int PluginGetAttrFloat(const CodecInfo& info, const char* attribute, float* value)
+int PluginGetAttrFloat(const CodecInfo& info, const char* attribute,
+		       float* value)
 {
     const AttributeInfo* attr = info.FindAttribute(attribute);
-    const char* n = info.privatename.c_str();
+    const char* n = info.GetPrivateName();
 
     if (attr && attr->GetKind() == AttributeInfo::Float)
     {
 	*value = RegReadFloat(n, attribute, attr->GetDefaultFloat());
 	return 0;
     }
-    AVM_WRITE(n, "GetAttrFloat unsupported attribute or incorrect value %s = %f\n", attribute, value);\
+    AVM_WRITE(n, "GetAttrFloat unsupported attribute or incorrect value %s = %f\n", attribute, *value);\
     return -1;
 }
 
 int PluginSetAttrFloat(const CodecInfo& info, const char* attribute, float value)
 {
     const AttributeInfo* attr = info.FindAttribute(attribute);
-    const char* n = info.privatename.c_str();
+    const char* n = info.GetPrivateName();
 
     if (attr && attr->GetKind() == AttributeInfo::Float
 	&& attr->IsValid(value))
@@ -859,7 +850,7 @@ int PluginSetAttrFloat(const CodecInfo& info, const char* attribute, float value
 int PluginGetAttrInt(const CodecInfo& info, const char* attribute, int* value)
 {
     const AttributeInfo* attr = info.FindAttribute(attribute);
-    const char* n = info.privatename.c_str();
+    const char* n = info.GetPrivateName();
 
     if (attr && (attr->GetKind() == AttributeInfo::Integer
 		 || attr->GetKind() == AttributeInfo::Select))
@@ -867,14 +858,14 @@ int PluginGetAttrInt(const CodecInfo& info, const char* attribute, int* value)
 	*value = RegReadInt(n, attribute, attr->GetDefault());
         return 0;
     }
-    AVM_WRITE(n, "GetAttrInt unsupported attribute or incorrect value %s = %d\n", attribute, value);\
+    AVM_WRITE(n, "GetAttrInt unsupported attribute or incorrect value %s = %d\n", attribute, *value);\
     return -1;
 }
 
 int PluginSetAttrInt(const CodecInfo& info, const char* attribute, int value)
 {
     const AttributeInfo* attr = info.FindAttribute(attribute);
-    const avm::string n = info.privatename;
+    const char* n = info.GetPrivateName();
 
     if (attr && (attr->GetKind() == AttributeInfo::Integer
 		 || attr->GetKind() == AttributeInfo::Select)
@@ -887,10 +878,11 @@ int PluginSetAttrInt(const CodecInfo& info, const char* attribute, int value)
     return -1;
 }
 
-int PluginGetAttrString(const CodecInfo& info, const char* attribute, const char** value)
+int PluginGetAttrString(const CodecInfo& info, const char* attribute,
+			const char** value)
 {
     const AttributeInfo* attr = info.FindAttribute(attribute);
-    const char* n = info.privatename.c_str();
+    const char* n = info.GetPrivateName();
 
     if (value && attr && (attr->GetKind() == AttributeInfo::String))
     {
@@ -901,10 +893,11 @@ int PluginGetAttrString(const CodecInfo& info, const char* attribute, const char
     return -1;
 }
 
-int PluginSetAttrString(const CodecInfo& info, const char* attribute, const char* value)
+int PluginSetAttrString(const CodecInfo& info, const char* attribute,
+			const char* value)
 {
     const AttributeInfo* attr = info.FindAttribute(attribute);
-    const char* n = info.privatename.c_str();
+    const char* n = info.GetPrivateName();
 
     if (value && attr && (attr->GetKind() == AttributeInfo::String))
 	return RegWriteString(n, attribute, value);
@@ -913,7 +906,9 @@ int PluginSetAttrString(const CodecInfo& info, const char* attribute, const char
     return -1;
 }
 
-const CodecInfo* CodecInfo::match(fourcc_t fcccodec, CodecInfo::Media cimedia, const CodecInfo* start, CodecInfo::Direction cdir)
+const CodecInfo* CodecInfo::match(fourcc_t fcccodec, CodecInfo::Media cimedia,
+				  const CodecInfo* start,
+				  CodecInfo::Direction cdir)
 {
     if (video_codecs.size() == 0 && audio_codecs.size() == 0)
     {
@@ -923,7 +918,7 @@ const CodecInfo* CodecInfo::match(fourcc_t fcccodec, CodecInfo::Media cimedia, c
 	CreateDecoderVideo(bi, 0, 0);
     }
 
-    avm::vector<CodecInfo>& c =
+    const avm::vector<CodecInfo>& c =
 	(cimedia == Video) ? video_codecs : audio_codecs;
 
     for (unsigned i = 0; i < c.size(); i++)
@@ -935,7 +930,7 @@ const CodecInfo* CodecInfo::match(fourcc_t fcccodec, CodecInfo::Media cimedia, c
 	    continue;
 	}
 
-	CodecInfo& ci = c[i];
+	const CodecInfo& ci = c[i];
 
 	if (((int)ci.direction & (int)cdir) != (int)cdir)
 	    continue;
@@ -970,10 +965,11 @@ const CodecInfo* CodecInfo::match(CodecInfo::Media cimedia, const char* pname)
 	CreateDecoderVideo(bi, 0, 0);
     }
 
-    avm::vector<CodecInfo>& c = (cimedia == Video ) ? video_codecs : audio_codecs;
+    const avm::vector<CodecInfo>& c = (cimedia == Video )
+	? video_codecs : audio_codecs;
     for (unsigned i = 0; i < c.size(); i++)
     {
-	CodecInfo& ci = c[i];
+	const CodecInfo& ci = c[i];
 
 	if (strcmp(ci.GetPrivateName(), pname) == 0
 	    || strcmp(ci.GetName(), pname) == 0)
@@ -983,10 +979,9 @@ const CodecInfo* CodecInfo::match(CodecInfo::Media cimedia, const char* pname)
     return 0;
 }
 
-extern "C" int GetAvifileVersion()
+AVM_END_NAMESPACE;
+
+int GetAvifileVersion()
 {
-    out.setDebugLevel(0, 0);
     return AVIFILE_VERSION;
 }
-
-AVM_END_NAMESPACE;
