@@ -18,8 +18,7 @@ struct ConfigEntry
 	Int,
 	Float,
 	Binary
-    };
-    Types type;
+    } type;
     avm::string appname;
     avm::string valname;
     avm::string value;
@@ -29,14 +28,19 @@ struct ConfigEntry
 	float f;
     };
 
-    ConfigEntry(const char* appname = 0, const char* valname = 0);
-    ~ConfigEntry();
-    ConfigEntry(const ConfigEntry& e);
+    ConfigEntry(const char* _appname = 0, const char* _valname = 0, int _i = 0)
+	: type(Int), appname(_appname), valname(_valname), i(_i) {}
+    ConfigEntry(const char* _appname, const char* _valname, float _f)
+	: type(Float), appname(_appname), valname(_valname), f(_f) {}
+    ConfigEntry(const char* _appname, const char* _valname, const char* _v)
+	: type(Binary), appname(_appname), valname(_valname), value(_v) {}
+    ~ConfigEntry() {}
+    ConfigEntry(const ConfigEntry& e) { operator=(e); }
     ConfigEntry& operator= (const ConfigEntry& e);
 
-    void SetFloat(float _f) { value.erase(); f = _f; type = Float; }
-    void SetInt(int _i) { value.erase(); i = _i; type = Int; }
-    void SetString(const char* _value) { value = _value; type = Binary; }
+    ConfigEntry& SetFloat(float _f) { value.erase(); f = _f; type = Float; return *this; }
+    ConfigEntry& SetInt(int _i) { value.erase(); i = _i; type = Int; return *this; }
+    ConfigEntry& SetString(const char* _value) { value = _value; type = Binary; return *this; }
 };
 
 struct ConfigFile
@@ -51,7 +55,7 @@ struct ConfigFile
     void Close();
     void Save(); 
     void Open(const char* fn);
-    ConfigEntry *Find(const char* appname, const char* valname);
+    ConfigEntry* Find(const char* appname, const char* valname);
     void push_back(const ConfigEntry& e);
 
     void sort();
