@@ -208,7 +208,9 @@ static IAudioDecoder* audiodec_CreateAudioDecoder(const CodecInfo& info, const W
 
 AVM_END_NAMESPACE;
 
-extern "C" const avm::codec_plugin_t avm_codec_plugin_audiodec =
+extern "C" avm::codec_plugin_t avm_codec_plugin_audiodec;
+
+avm::codec_plugin_t avm_codec_plugin_audiodec =
 {
     PLUGIN_API_VERSION,
 
