@@ -1,7 +1,4 @@
 #include "fillplugins.h"
-#ifdef HAVE_LIBDIVXENCORE
-#include <encore2.h>
-#endif
 #include "videodecoder.h"
 #include "videoencoder.h"
 #include "avm_fourcc.h"
@@ -14,7 +11,6 @@
 #include <string.h>
 
 AVM_BEGIN_NAMESPACE;
-#undef DIVXBIN
 
 #ifdef DIVXBIN
 #include <dlfcn.h>
@@ -27,6 +23,9 @@ PLUGIN_TEMP(divx4);
 static const int DIVX4_MAX_QUALITY = 6;
 static const char* strDebugEnc = "DivX4 plugin";
 
+#ifndef DECORE_VERSION
+#define DECORE_VERSION 0
+#endif
 
 #if DECORE_VERSION >= 20021112
 typedef void* divxhandle_t;
@@ -78,17 +77,20 @@ public:
     int init()
     {
 #ifdef DIVXBIN
-	m_pDll = dlopen(divxencore, RTLD_LAZY);
-	if (!m_pDll)
+	if (!m_pDll && !(m_pDll = dlopen(divxdecore, RTLD_LAZY)))
 	{
 	    divx4_error_set("can't open %s", divxdecore);
-            return -1;
+	    return -1;
 	}
-	m_pDecore = (pDecoreFun) dlsym(m_pDll, "decore");
-	if (!m_pDecore)
+	if (!(m_pDecore = (pDecoreFun) dlsym(m_pDll, "decore")))
 	{
 	    divx4_error_set("can't resolve %s:decore", divxdecore);
-            dlclose(m_pDll);
+            return -1;
+	}
+
+	int ver = m_pDecore(0, DEC_OPT_VERSION, 0, 0);
+	if ((DECORE_VERSION == 20020322 && ver != 2)) {
+	    divx4_error_set("plugin version %d is different from %s library version %d!", DECORE_VERSION, divxdecore, ver);
             return -1;
 	}
 #else
@@ -133,7 +135,7 @@ public:
 	PluginGetAttrInt(m_Info, divx4str_saturation, &m_iLastSaturation);
 
 	m_YvAttrs.push_back(AttributeInfo(divx4str_postprocessing,
-					  "Image postprocessing mode ( 6 slowest )",
+					  "Image postprocessing mode (6 slowest)",
 					  AttributeInfo::Integer, 0, 6));
 	m_YvAttrs.push_back(AttributeInfo(divx4str_maxauto,
 					  "Maximum autoquality level",
@@ -157,35 +159,35 @@ public:
     }
     virtual int Start()
     {
+	fprintf(stderr,"Decore  START %d\n", DECORE_VERSION);
 #if DECORE_VERSION >= 20021112
-	DEC_INIT init;
-	memset(&init, 0, sizeof(init));
+	DEC_INIT dinit;
+	memset(&dinit, 0, sizeof(dinit));
 	switch(m_Info.fourcc)
 	{
-	case fccDIV3: init.codec_version = 311; break;
-	case fccDIVX: init.codec_version = 412; break;
+	case fccDIV3: dinit.codec_version = 311; break;
+	case fccDIVX: dinit.codec_version = 412; break;
 	default:
-	case fccDX50: init.codec_version = 500; break;
+	case fccDX50: dinit.codec_version = 500; break;
 	}
-
-	int result = m_pDecore(&m_Handle, (divxopts_t)DEC_OPT_INIT, &init, 0);
+	AVM_WRITE(strDebugEnc, "Decore  Version %d\n", dinit.codec_version);
+	int result = m_pDecore(&m_Handle, (divxopts_t)DEC_OPT_INIT, &dinit, 0);
 	if (result || !m_Handle)
 	{
     	    divx4_error_set("Error %d creating decoder instance", result);
 	    return -1;
 	}
-	result = m_pDecore(m_Handle, (divxopts_t)DEC_OPT_SETOUT, &m_Dest, 0);
-	if(result) // unacceptable color space
-	{
+	if ((result = m_pDecore(m_Handle, (divxopts_t)DEC_OPT_SETOUT, &m_Dest, 0)))
+	{ // unacceptable color space
 	    divx4_error_set("Error %d setting output", 	result);
 	    return -1;
 	}
 #else /* version < 20021112 */
 	DEC_PARAM param;
 
-        memset(&param, 0, sizeof(param));
-	int csp = m_Dest.biCompression;
-	// AVM_WRITE("DivX4 plugin", "csp: 0x%x  %.4s  bitcount: %d height: %d\n", csp, (char*)&csp, m_obh.biBitCount, m_obh.biHeight);
+	memset(&param, 0, sizeof(param));
+	uint32_t& csp = m_Dest.biCompression;
+	//AVM_WRITE(strDebugEnc, "csp: 0x%x  %.4s  bitcount: %d height: %d\n", csp, (char*)&csp, m_Dest.biBitCount, m_Dest.biHeight);
 
 	if (csp == 0 || csp == 3)
 	{
@@ -200,41 +202,24 @@ public:
 		}
                 // 16 bit with csp == 0  is 15bit
                 /* fall through */
-	    case 15:
-		param.output_format = (up) ? DEC_RGB555 : DEC_RGB555_INV;
-		break;
-	    case 24:
-		param.output_format = (up) ? DEC_RGB24 : DEC_RGB24_INV;
-		break;
-	    case 32:
-		param.output_format = (up) ? DEC_RGB32 : DEC_RGB32_INV;
-		break;
-	    default:
-		return -1;
+	    case 15: param.output_format = (up) ? DEC_RGB555 : DEC_RGB555_INV; break;
+	    case 24: param.output_format = (up) ? DEC_RGB24 : DEC_RGB24_INV; break;
+	    case 32: param.output_format = (up) ? DEC_RGB32 : DEC_RGB32_INV; break;
+	    default: return -1;
 	    }
 	}
 	else
 	{
-	    switch(csp)
+	    switch (csp)
 	    {
-	    case IMG_FMT_I420:
-		param.output_format = DEC_420;
-		break;
-	    case IMG_FMT_YV12:
-		param.output_format = DEC_YV12;
-		break;
-	    case IMG_FMT_YUY2:
-		param.output_format = DEC_YUV2;
-		break;
+	    case IMG_FMT_I420: param.output_format = DEC_420; break;
+	    case IMG_FMT_YV12: param.output_format = DEC_YV12; break;
+	    case IMG_FMT_YUY2: param.output_format = DEC_YUV2; break;
 	    case IMG_FMT_I422:
-	    case IMG_FMT_UYVY:
-		param.output_format = DEC_UYVY;
-		break;
-	    default:
-                return -1;
+	    case IMG_FMT_UYVY: param.output_format = DEC_UYVY; break;
+	    default: return -1;
 	    }
 	}
-
 	param.x_dim = m_Dest.biWidth;
 	param.y_dim = labs(m_Dest.biHeight);
 	param.time_incr = 15;
@@ -300,7 +285,7 @@ public:
 	memset(&param, 0, sizeof(param));
 
 	// leave here for some time - until all users will use new headers
-	param.bitstream = (void*) src;
+	param.bitstream = const_cast<void*>(src);
 	param.length = size;
 
 	if (pImage)
@@ -339,49 +324,55 @@ public:
 #endif /* DEC_OPT_GAMMA */
 #endif /* 20021112 */
 	}
-
+        int r;
 #if DECORE_VERSION >= 20021112
-	m_pDecore(m_Handle, (divxopts_t)DEC_OPT_FRAME, &param, 0);
+	r = m_pDecore(m_Handle, (divxopts_t)DEC_OPT_FRAME, &param, 0);
 #else /* version < 20021112 */
 #ifdef USE_311_DECODER
 #if DECORE_VERSION < 20020303
 	if(m_bCompat311)
 	{
-	    m_pDecore(m_Handle, DEC_OPT_FRAME_311, &param, 0);
+	    r = m_pDecore(m_Handle, DEC_OPT_FRAME_311, &param, 0);
 	}
 	else
 #endif /* 20020303 */
 #endif /* USE_311_DECODER */
 	{
-	    m_pDecore(m_Handle, DEC_OPT_FRAME, &param, 0);
+	    r = m_pDecore(m_Handle, DEC_OPT_FRAME, &param, 0);
 	}
 #endif
 	pImage->SetQuality((float) m_iLastPPMode / DIVX4_MAX_QUALITY);
+	//fprintf(stderr,"Decore  result %d\n", r);
+	if (r != 0) {
+	    AVM_WRITE(strDebugEnc, "Reinitializing codec\n");
+	    Restart(); // restart codec completely in this case
+	}
 
 	return size;
     }
     virtual int SetDestFmt(int bits = 24, fourcc_t csp = 0)
     {
-	if (!bits)
-	    bits = csp;
+	//AVM_WRITE(strDebugEnc, "SetDestFmt  %x %x\n", bits, csp);
+	if (csp)
+            bits = csp;
 
-	switch(bits)
+	switch (bits)
 	{
 	case 15:
 	case 16:
 	case 24:
 	case 32:
 	    m_Dest.SetBits(bits);
-            break;
+	    break;
 	case IMG_FMT_I420:
 	case IMG_FMT_YV12:
 	case IMG_FMT_YUY2:
 	case IMG_FMT_I422:
 	case IMG_FMT_UYVY:
-	    m_Dest.SetSpace(csp);
+	    m_Dest.SetSpace(bits);
 	    break;
 	default:
-            return -1;
+	    return -1;
 	}
 #if DECORE_VERSION >= 20021112
 	if(m_Handle)
@@ -468,9 +459,9 @@ class DIVX_VideoEncoder: public IVideoEncoder
     int m_iCSP;
     bool m_bRtMode;
     int (*m_pEncore)(void *handle,   // handle   - the handle of the call
-		  int enc_opt,    // enc_opt  - the option for encodin
-		  void *param1,   // param1   - the parameter 1 (its a
-		  void *param2);  // param2   - the parameter 2 (its a
+		     int enc_opt,    // enc_opt  - the option for encodin
+		     void *param1,   // param1   - the parameter 1 (its a
+		     void *param2);  // param2   - the parameter 2 (its a
 public:
     DIVX_VideoEncoder(const CodecInfo& info, int compressor, const BITMAPINFOHEADER& bh)
 	:IVideoEncoder(info), m_bh(bh), m_obh(bh),
@@ -554,10 +545,10 @@ public:
 #endif
 	memset(&param, 0, sizeof(param));
 #if ENCORE_MAJOR_VERSION < 5200
-	param.x_dim=m_bh.biWidth;
+	param.x_dim = m_bh.biWidth;
 	//param.y_dim=m_bh.biHeight;// labs(m_bh.biHeight);
-	param.y_dim=labs(m_bh.biHeight);
-	param.framerate=30;//frames/sec
+	param.y_dim = labs(m_bh.biHeight);
+	param.framerate = 30;//frames/sec
 #else
 	param.input_clock = 1000000;
 	param.input_frame_period = 33333;
@@ -634,7 +625,7 @@ public:
 	if (param.quality == 1)
 	{
 	    m_bRtMode=true;
-	    int quality=GetQuality();
+	    int quality = 0;//GetQuality();
 	    m_iQuant=int(1+.003*(10000-quality));
 	    AVM_WRITE(strDebugEnc, "New quant: %d\n", m_iQuant);
 	    if(m_iQuant>31)
@@ -684,7 +675,8 @@ public:
             ci = new CImage(src, &m_bh);
 	    //src->GetFmt()->Print();
 	    //AVM_WRITE(strDebugEnc, "enconding format doesn't match!\n");
-	    //return -1;
+            if (!ci)
+		return -1;
 	}
 	ENC_FRAME param;
 	memset(&param, 0, sizeof(param));
@@ -759,7 +751,9 @@ static IVideoEncoder* divx4_CreateVideoEncoder(const CodecInfo& info, fourcc_t c
 
 AVM_END_NAMESPACE;
 
-extern "C" const avm::codec_plugin_t avm_codec_plugin_divx4 =
+extern "C" avm::codec_plugin_t avm_codec_plugin_divx4;
+
+avm::codec_plugin_t avm_codec_plugin_divx4 =
 {
     PLUGIN_API_VERSION,
 
