@@ -2,7 +2,7 @@
 #define AVIFILE_FFAUDIODECODER_H
 
 #include "audiodecoder.h"
-#include "avcodec.h"
+#include "avm_avcodec.h"
 
 AVM_BEGIN_NAMESPACE;
 
