@@ -196,27 +196,30 @@ int FFVideoEncoder::EncodeFrame(const CImage* src, void* dest, int* is_keyframe,
 
 		avoption_parse(m_pAvContext, codec->options, arg);
 	    }
+	    }
+	}
 #endif
     }
 
-    CImage* ci = 0;
+    const CImage* ci = src;
+    CImage* conv = 0;
     //printf("CODEC format  0x%x\n", src->Format());
     if (src->Format() != IMG_FMT_YV12)
     {
         printf("Converted\n");
-        ci = new CImage(src, IMG_FMT_YV12);
+	ci = conv = new CImage(src, IMG_FMT_YV12);
+	if (!conv)
+            return -1;
     }
-    else
-        ci = (CImage*) src;
 
     AVFrame f; // YV12 only
     memset(&f, 0, sizeof(AVFrame));
-    f.data[0] = ci->Data(0);
-    f.data[1] = ci->Data(2);
-    f.data[2] = ci->Data(1);
-    f.linesize[0] = src->Stride(0);
-    f.linesize[1] = src->Stride(2);
-    f.linesize[2] = src->Stride(1);
+    f.data[0] = const_cast<uint8_t*>(ci->Data(0));
+    f.data[1] = const_cast<uint8_t*>(ci->Data(2));
+    f.data[2] = const_cast<uint8_t*>(ci->Data(1));
+    f.linesize[0] = ci->Stride(0);
+    f.linesize[1] = ci->Stride(2);
+    f.linesize[2] = ci->Stride(1);
     //printf("ECDING FF  %p %p %p   sz:%d\n", f.data[0], f.data[1], f.data[2], GetOutputSize());
     //printf("ECDING FF  %d %d %d\n", f.linesize[0], f.linesize[1], f.linesize[2]);
 
@@ -229,8 +232,8 @@ int FFVideoEncoder::EncodeFrame(const CImage* src, void* dest, int* is_keyframe,
 	*is_keyframe = m_pAvContext->coded_frame->key_frame ? 16 : 0;
 	//printf("KEYFRAME %d\n", *is_keyframe);
     }
-    if (ci != src)
-        ci->Release();
+    if (conv)
+        conv->Release();
 
     return hr;
 }
