@@ -64,9 +64,13 @@ static void add_divx(avm::vector<CodecInfo>& ci)
     static const fourcc_t wmv2_codecs[] = { fccWMV2, fccwmv2, 0 };
 
     static const fourcc_t wmv3_codecs[] = {
-	RIFFINFO_WMV3, RIFFINFO_wmv3, fccWMV2, fccwmv2, fccWMV1, fccwmv1, 0
+	RIFFINFO_WMV3, RIFFINFO_wmv3, fccWMV2, fccwmv2, fccWMV1, fccwmv1,
+        mmioFOURCC('M', 'S', 'S', '2'), mmioFOURCC('W', 'M', 'V', 'P'),
+	0
     };
-    static const fourcc_t wmv39_codecs[] = { RIFFINFO_WMV3, RIFFINFO_wmv3, 0 };
+    static const fourcc_t wmv39_codecs[] = { RIFFINFO_WMV3, RIFFINFO_wmv3,
+    mmioFOURCC('W', 'M', 'V', 'P'),
+    0 };
     /* divx directshow is able to decode large variety of formats */
     static const fourcc_t div3_codecsd[] = { DIVX_FCCS, 0 };
     static const fourcc_t div5_codecsd[] = { fccDIV5, DIVX_FCCS, 0 };
@@ -97,38 +101,38 @@ static void add_divx(avm::vector<CodecInfo>& ci)
     ds1.push_back(AttributeInfo("Hue", "Hue", AttributeInfo::Integer, 0, 100));
 
     // DS player
-    ci.push_back(CodecInfo(div5_codecsd, "DivX ;-) VKI DirectShow", "divxcvki.ax",
+    ci.push_back(CodecInfo(div5_codecsd, "W32 DivX ;-) VKI DirectShow", "divxcvki.ax",
 			   divx_about, CodecInfo::DShow_Dec, "divxvkids",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_DivxDecompressorCF, vs_empty, ds1));
     // DS player
-    ci.push_back(CodecInfo(div3_codecsd, "DivX ;-) DirectShow", "divx_c32.ax",
+    ci.push_back(CodecInfo(div3_codecsd, "W32 DivX ;-) DirectShow", "divx_c32.ax",
 			   divx_about, CodecInfo::DShow_Dec, "divxds",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_DivxDecompressorCF, vs_empty, ds1));
     // for encoding
-    ci.push_back(CodecInfo(div5_codecs,	"DivX ;-) VKI (Low-Motion)", "divxcvki.dll",
+    ci.push_back(CodecInfo(div5_codecs,	"W32 DivX ;-) VKI (Low-Motion)", "divxcvki.dll",
 			   divx_about, CodecInfo::Win32, "divxvkil",
 			   CodecInfo::Video, CodecInfo::Both, 0, vs, ds));
     // for encoding
-    ci.push_back(CodecInfo(div6_codecs, "DivX ;-) VKI (Fast-Motion)", "divxcfvk.dll",
+    ci.push_back(CodecInfo(div6_codecs, "W32 DivX ;-) VKI (Fast-Motion)", "divxcfvk.dll",
 			   divx_about, CodecInfo::Win32, "divxvkif",
 			   CodecInfo::Video, CodecInfo::Both, 0, vs, ds));
     // for encoding
-    ci.push_back(CodecInfo(div3_codecs,	"DivX ;-) Low-Motion", "divxc32.dll",
+    ci.push_back(CodecInfo(div3_codecs,	"W32 DivX ;-) Low-Motion", "divxc32.dll",
 			   divx_about, CodecInfo::Win32, "divx",
 			   CodecInfo::Video, CodecInfo::Both, 0, vs, ds));
     // for encoding
-    ci.push_back(CodecInfo(div4_codecs, "DivX ;-) Fast-Motion", "divxc32f.dll",
+    ci.push_back(CodecInfo(div4_codecs, "W32 DivX ;-) Fast-Motion", "divxc32f.dll",
 			   divx_about, CodecInfo::Win32, "divxf",
 			   CodecInfo::Video, CodecInfo::Both, 0, vs, ds));
 
-    ci.push_back(CodecInfo(wmv1_codecs, "Windows Media Video 7 DirectShow",
+    ci.push_back(CodecInfo(wmv1_codecs, "W32 Windows Media Video 7 DirectShow",
 			   "wmvds32.ax",
 			   none_about, CodecInfo::DShow_Dec, "wmv7",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_WMV1, vs_empty, ds1));
-    ci.push_back(CodecInfo(wmv2_codecs, "Windows Media Video 8 DirectShow",
+    ci.push_back(CodecInfo(wmv2_codecs, "W32 Windows Media Video 8 DirectShow",
 			   "wmv8ds32.ax",
 			   none_about, CodecInfo::DShow_Dec, "wmv8",
 			   CodecInfo::Video, CodecInfo::Decode,
@@ -140,25 +144,25 @@ static void add_divx(avm::vector<CodecInfo>& ci)
     wmattr.push_back(AttributeInfo("Adapt Post Process Mode", "Adapt Post Process Mode", AttributeInfo::Integer, 0, 1));
     wmattr.push_back(AttributeInfo("Deinterlace", "Deinterlace", AttributeInfo::Integer, 0, 1));
 
-    ci.push_back(CodecInfo(wmv3_codecs,	"Windows Media Video DMO",
+    ci.push_back(CodecInfo(wmv3_codecs,	"W32 Windows Media Video DMO",
 			   "wmvdmod.dll",
 			   none_about, CodecInfo::DMO, "wmvdmod",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_WMV3DMO, 0, wmattr));
-    ci.push_back(CodecInfo(wmv39_codecs, "Windows Media Video 9 DMO",
+    ci.push_back(CodecInfo(wmv39_codecs, "W32 Windows Media Video 9 DMO",
 			   "wmv9dmod.dll",
 			   none_about, CodecInfo::DMO, "wmv9dmod",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_WMV39DMO));
 #if 0
-    ci.push_back(CodecInfo(wmv1_codecs,	"WMV enc dll",
+    ci.push_back(CodecInfo(wmv1_codecs,	"W32 WMV enc dll",
 			   "wmvdmoe.dll",
 			   none_about, CodecInfo::Win32, "wmvdmo_enc",
 			   CodecInfo::Video, CodecInfo::Encode));
 #endif
 #if 0
     // doesn't work 0x80004005
-    ci.push_back(CodecInfo(wmv2_codecs,	"WMV8 DMO decoder",
+    ci.push_back(CodecInfo(wmv2_codecs,	"W32 WMV8 DMO decoder",
 			   "wmv8dmod.dll",
 			   none_about, CodecInfo::DMO, "wmv8dmod",
 			   CodecInfo::Video, CodecInfo::Decode,
@@ -172,10 +176,10 @@ static void add_divx(avm::vector<CodecInfo>& ci)
 	fccMP42, fccmp42, fccmp43,
         fccMPG4, fccmpg4, fccDIV2, fccdiv2, 0
     };
-    ci.push_back(CodecInfo(mpg4_codecs, "Microsoft MPEG-4 DirectShow", "mpg4ds32.ax",
+    ci.push_back(CodecInfo(mpg4_codecs, "W32 Microsoft MPEG-4 DirectShow", "mpg4ds32.ax",
 			   mpg4_about, CodecInfo::DShow_Dec, "mpeg4ds",
 			   CodecInfo::Video, CodecInfo::Decode));
-    ci.push_back(CodecInfo(mpg4_codecs, "Microsoft MPEG-4", "mpg4c32.dll",
+    ci.push_back(CodecInfo(mpg4_codecs, "W32 Microsoft MPEG-4", "mpg4c32.dll",
 			   mpg4_about, CodecInfo::Win32, "mpeg4",
 			   CodecInfo::Video, CodecInfo::Both, 0, vs, ds));
 
@@ -186,7 +190,7 @@ static void add_angel(avm::vector<CodecInfo>& ci)
     // crashing - using divx instead of this
     static const fourcc_t apxx_codecs[] = { fccAP41, fccap41, fccAP42, fccap42, 0 };
 
-    ci.push_back(CodecInfo(apxx_codecs, "AngelPotion MPEG-4", "apmpg4v1.dll",
+    ci.push_back(CodecInfo(apxx_codecs, "W32 AngelPotion MPEG-4", "apmpg4v1.dll",
 			   none_about, CodecInfo::Win32, "angelpotion"));
 }
 
@@ -195,11 +199,11 @@ static void add_ati(avm::vector<CodecInfo>& ci)
     static const fourcc_t vcr1_codecs[] = { fccVCR1, 0 };
     static const fourcc_t vcr2_codecs[] = { fccVCR2, 0 };
 
-    ci.push_back(CodecInfo(vcr1_codecs, "ATI VCR-1", "ativcr1.dll",
+    ci.push_back(CodecInfo(vcr1_codecs, "W32 ATI VCR-1", "ativcr1.dll",
 			   none_about, CodecInfo::Win32, "vcr1",
 			   CodecInfo::Video, CodecInfo::Decode));
 
-    ci.push_back(CodecInfo(vcr2_codecs, "ATI VCR-2", "ativcr2.dll",
+    ci.push_back(CodecInfo(vcr2_codecs, "W32 ATI VCR-2", "ativcr2.dll",
 			   none_about, CodecInfo::Win32, "vcr2",
 			   CodecInfo::Video, CodecInfo::Decode));
 }
@@ -209,47 +213,41 @@ static void add_asus(avm::vector<CodecInfo>& ci)
     static const fourcc_t asv1_codecs[] = { fccASV1, 0 };
     static const fourcc_t asv2_codecs[] = { fccASV2, 0 };
 
-    ci.push_back(CodecInfo(asv1_codecs, "ASUS V1 - crash", "asusasvd.dll",
+    ci.push_back(CodecInfo(asv1_codecs, "W32 ASUS V1 - crash", "asusasvd.dll",
 			   none_about, CodecInfo::Win32, "asv1",
 			   CodecInfo::Video, CodecInfo::Decode));
-
-    ci.push_back(CodecInfo(asv2_codecs, "ASUS V2", "asusasv2.dll",
+    ci.push_back(CodecInfo(asv2_codecs, "W32 ASUS V2", "asusasv2.dll",
 			   none_about, CodecInfo::Win32, "asv2",
                            CodecInfo::Video, CodecInfo::Decode));
 }
 
 static void add_brooktree(avm::vector<CodecInfo>& ci)
 {
-    static const char* brook_about = "BtV Media Stream Version 1.0\n"
-	"Copyright Brooktree Corporation 1994-1997\n";
-    static const fourcc_t bt20_codecs[] = {
-	mmioFOURCC('B', 'T', '2', '0'), 0 };
-    static const fourcc_t yuv411_codecs[] = {
-	mmioFOURCC('Y', '4', '1', 'P'), 0 };
-    static const fourcc_t yvu9_codecs[] = {
-	mmioFOURCC('Y', 'V', 'Y', '9'), 0 };
+    static const char* brook_about = "W32 BtV Media Stream Version 1.0"
+	"Copyright Brooktree Corporation 1994-1997";
+    static const fourcc_t bt20_codecs[] = { mmioFOURCC('B', 'T', '2', '0'), 0 };
+    static const fourcc_t yuv411_codecs[] = { mmioFOURCC('Y', '4', '1', 'P'), 0 };
+    static const fourcc_t yvu9_codecs[] = { mmioFOURCC('Y', 'V', 'Y', '9'), 0 };
 
     // missing: Called unk_GetWindowDC
 
-    ci.push_back(CodecInfo(bt20_codecs, "Brooktree(r) ProSummer Video",
+    ci.push_back(CodecInfo(bt20_codecs, "W32 Brooktree(r) ProSummer Video",
 			   "btvvc32.drv",
 			   brook_about, CodecInfo::Win32, "btree",
                            CodecInfo::Video, CodecInfo::Both));
-    ci.push_back(CodecInfo(yuv411_codecs, "Brooktree(r) YUV411 Raw",
+    ci.push_back(CodecInfo(yuv411_codecs, "W32 Brooktree(r) YUV411 Raw",
 			   "btvvc32.drv",
 			   brook_about, CodecInfo::Win32, "btree_yuv411",
                            CodecInfo::Video, CodecInfo::Both));
-
-    ci.push_back(CodecInfo(yvu9_codecs, "Brooktree(r) YVU9 Raw",
+    ci.push_back(CodecInfo(yvu9_codecs, "W32 Brooktree(r) YVU9 Raw",
 			   "btvvc32.drv",
 			   brook_about, CodecInfo::Win32, "btree_yvu9",
                            CodecInfo::Video, CodecInfo::Decode));
-
 }
 
 static void add_dvsd(avm::vector<CodecInfo>& ci)
 {
-    static const char* dvsd_about = "Sony Digital Video (DV)";
+    static const char* dvsd_about = "W32 Sony Digital Video (DV)";
     static const fourcc_t dvsd_codecs[] = {
 	fccdvsd, fccDVSD, fccdvhd, fccdvsl, 0 };
     static const GUID CLSID_DVSD =
@@ -257,7 +255,7 @@ static void add_dvsd(avm::vector<CodecInfo>& ci)
 	0xB1B77C00, 0xC3E4, 0x11CF,
 	{0xAF, 0x79, 0x00, 0xAA, 0x00, 0xB6, 0x7A, 0x42}
     };
-    ci.push_back(CodecInfo(dvsd_codecs,	"DVSD (MainConcept)", "qdv.dll",
+    ci.push_back(CodecInfo(dvsd_codecs,	"W32 DVSD (MainConcept)", "qdv.dll",
 			   dvsd_about, CodecInfo::DShow_Dec, "qdv",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_DVSD));
@@ -292,7 +290,7 @@ static void add_divx4(avm::vector<CodecInfo>& ci)
     ds1.push_back(AttributeInfo("postprocessing",
 				"Image postprocessing mode ( 6 slowest )",
 				AttributeInfo::Integer, 0, 6));
-    static const char* opendivxw_about = "Win32 DivX 4.0 Beta Codec MPEG-4";
+    static const char* opendivxw_about = "W32 DivX 4.0 Beta Codec MPEG-4";
     static const fourcc_t opendivxw_codecs[] =
     {
 	fccDIVX, fccdivx, fccDIV1, fccdiv1, fccMP4S, fccmp4s, 0x4,
@@ -318,18 +316,18 @@ static void add_divx4(avm::vector<CodecInfo>& ci)
 
     // implementation of some Direct Draw interface is not necessary
     // check fails but codec works
-    ci.push_back(CodecInfo(opendivxw_codecs, "Win32 DivX4 OpenDivX DirectShow",
+    ci.push_back(CodecInfo(opendivxw_codecs, "W32 DivX4 OpenDivX DirectShow",
 			   "divxdec.ax",
 			   opendivxw_about, CodecInfo::DShow_Dec, "divx4ds",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &IID_IDivxFilterInterface, vs_empty, ds));
-    ci.push_back(CodecInfo(div3_codecs, "Win32 DivX4 DivX ;-) DirectShow",
+    ci.push_back(CodecInfo(div3_codecs, "W32 DivX4 DivX ;-) DirectShow",
 			   "divxdec.ax",
 			   opendivxw_about, CodecInfo::DShow_Dec, "divx4ds311",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &IID_IDivxFilterInterface, vs_empty, ds));
 
-    ci.push_back(CodecInfo(divxall_codecs, "Win32 DivX4 4.0 Beta Codec",
+    ci.push_back(CodecInfo(divxall_codecs, "W32 DivX4 4.0 Beta Codec",
 			   "divx.dll",
 			   opendivxw_about, CodecInfo::Win32, "divx4vfw",
 			   CodecInfo::Video,
@@ -364,7 +362,7 @@ static void add_divx5(avm::vector<CodecInfo>& ci)
     ds1.push_back(AttributeInfo("postprocessing",
 				"Image postprocessing mode ( 6 slowest )",
 				AttributeInfo::Integer, 0, 6));
-    static const char* opendivxw_about = "Win32 DivX 5.0 MPEG-4";
+    static const char* opendivxw_about = "W32 DivX 5.0 MPEG-4";
     static const fourcc_t opendivxw_codecs[] =
     {
 	fccDIVX, fccdivx, fccDIV1, fccdiv1, fccMP4S, fccmp4s, 0x4, 0
@@ -390,19 +388,19 @@ static void add_divx5(avm::vector<CodecInfo>& ci)
 
     // implementation of some Direct Draw interface is not necessary
     // check fails but codec works
-    ci.push_back(CodecInfo(divxall_codecs, "Win32 DivX5 5.0 DirectShow",
+    ci.push_back(CodecInfo(divxall_codecs, "W32 DivX5 5.0 DirectShow",
 			   "divxdec.ax",
 			   opendivxw_about, CodecInfo::DShow_Dec, "divx4ds",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &IID_IDivxFilterInterface, vs_empty, ds));
-    ci.push_back(CodecInfo(div3_codecs, "Win32 DivX5 DirectShow 3.11 compatible decoder",
+    ci.push_back(CodecInfo(div3_codecs, "W32 DivX5 DirectShow 3.11 compatible decoder",
 			   "divxdec.ax",
 			   opendivxw_about, CodecInfo::DShow_Dec, "divx4ds311",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &IID_IDivxFilterInterface, vs_empty, ds));
 #if 0
     // is there someone who could 'make this' usable outside of Win32 :)
-    ci.push_back(CodecInfo(divxall_codecs, "Win32 DivX5 5.0 Codec MPEG-4",
+    ci.push_back(CodecInfo(divxall_codecs, "W32 DivX5 5.0 Codec MPEG-4",
 			   "divx5.dll",
 			   opendivxw_about, CodecInfo::Win32, "divx5vfw",
 			   CodecInfo::Video,
@@ -430,9 +428,9 @@ static void add_xvid(avm::vector<CodecInfo>& ci)
 
     avm::vector<AttributeInfo> ds1;
     static const char* xvid_about =
-	"Win32 XviD MPEG-4 (extra)\n"
-	"this code is very cool if you will download\n"
-	"Win32 xvid.dll from:\n"
+	"W32 XviD MPEG-4 (extra)<br>"
+	"this code is very cool if you will download"
+	"Win32 xvid.dll from:<br>"
 	"<a href=\"http://www.geocities.com/avihpit/xvid/post.html\">"
 	"http://www.geocities.com/avihpit/xvid/post.html</a>";
     static const fourcc_t xvid_codecs[] =
@@ -447,13 +445,13 @@ static void add_xvid(avm::vector<CodecInfo>& ci)
 	{0xb3, 0xfa, 0xe0, 0x53, 0x1b, 0x89, 0x7f, 0x98}
     };
 
-    ci.push_back(CodecInfo(xvid_codecs, "Win32 XviD MPEG-4 Video Decoder",
+    ci.push_back(CodecInfo(xvid_codecs, "W32 XviD MPEG-4 Video Decoder",
 			   "xvid.ax",
 			   xvid_about, CodecInfo::DShow_Dec, "xvidds",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &IID_IXvidDecoder, vs_empty, ds));
 
-    ci.push_back(CodecInfo(xvid_codecs, "Win32 XviD MPEG-4 Codec",
+    ci.push_back(CodecInfo(xvid_codecs, "W32 XviD MPEG-4 Codec",
 			   "xvid.dll",
 			   xvid_about, CodecInfo::Win32, "xvidvfw",
 			   CodecInfo::Video, CodecInfo::Decode,
@@ -489,25 +487,25 @@ static void add_indeo(avm::vector<CodecInfo>& ci)
     ds.push_back(AttributeInfo("Brightness", "Brightness", AttributeInfo::Integer, -100, 100));
     ds.push_back(AttributeInfo("Contrast", "Contrast", AttributeInfo::Integer, -100, 100));
     ds.push_back(AttributeInfo("Saturation", "Saturation", AttributeInfo::Integer, -100, 100));
-    ci.push_back(CodecInfo(iv50_codecs, "Indeo(r) Video 5.0 DirectShow", "ir50_32.dll",
+    ci.push_back(CodecInfo(iv50_codecs, "W32 Indeo(r) Video 5.0 DirectShow", "ir50_32.dll",
 			   ivxx_about, CodecInfo::DShow_Dec, "indeo5ds",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_IV50_Decoder, vs, ds));
     vs.push_back(AttributeInfo("QuickCompress", "Quick Compress", AttributeInfo::Integer, 0, 1));
     //vs.push_back(AttributeInfo("Transparency", "Transparency", AttributeInfo::Integer, 0, 1));
     //vs.push_back(AttributeInfo("Scalability", "Scalability", AttributeInfo::Integer, 0, 1));
-    ci.push_back(CodecInfo(iv50_codecs, "Indeo(r) Video 5.04", "ir50_32.dll",
+    ci.push_back(CodecInfo(iv50_codecs, "W32 Indeo(r) Video 5.04", "ir50_32.dll",
 			   ivxx_about, CodecInfo::Win32, "indeo5",
 			   CodecInfo::Video, CodecInfo::Both, 0, vs));
-    ci.push_back(CodecInfo(iv41_codecs,	"Indeo Video 4.1", "ir41_32.dll",
+    ci.push_back(CodecInfo(iv41_codecs,	"W32 Indeo(r) Video 4.1", "ir41_32.dll",
 			   ivxx_about, CodecInfo::Win32, "indeo4",
 			   CodecInfo::Video, CodecInfo::Both, 0, vs));
-    ci.push_back(CodecInfo(iv3132_codecs, "Indeo Video 3.1/3.2 decoder", "ir32_32.dll",
+    ci.push_back(CodecInfo(iv3132_codecs, "W32 Indeo(r) Video 3.1/3.2 decoder", "ir32_32.dll",
 			   ivxx_about, CodecInfo::Win32, "indeo3",
 			   CodecInfo::Video, CodecInfo::Decode));
 #if 1
     /* these two doesn't work and causes crashes */
-    ci.push_back(CodecInfo(iv32_codecs, "Indeo Video 3.2", "ir32_32.dll",
+    ci.push_back(CodecInfo(iv32_codecs, "W32 Indeo(r) Video 3.2", "ir32_32.dll",
 			   ivxx_about, CodecInfo::Win32, "indeo32_enc",
 			   CodecInfo::Video, CodecInfo::Encode));
     //ci.push_back(CodecInfo(iv31_codecs, "Indeo Video 3.1", "ir32_32.dll",
@@ -556,7 +554,7 @@ static void add_morgan(avm::vector<CodecInfo>& ci)
 			   &CLSID_MorganMjpeg, 0, vs));
     */
 
-    ci.push_back(CodecInfo(mjpg_codecs, "Morgan Motion JPEG", "m3jpeg32.dll",
+    ci.push_back(CodecInfo(mjpg_codecs, "W32 Morgan Motion JPEG", "m3jpeg32.dll",
 			   mjpg_about, CodecInfo::Win32, "morgands",
 			   // this is actually not a morgands, but we don't care (?)
 			   CodecInfo::Video,
@@ -575,7 +573,7 @@ static void add_mcmjpeg(avm::vector<CodecInfo>& ci)
 	0
     };
 
-    ci.push_back(CodecInfo(msjpeg_codecs, "M$ Motion JPEG", "mcmjpg32.dll",
+    ci.push_back(CodecInfo(msjpeg_codecs, "W32 Microsoft Motion JPEG", "mcmjpg32.dll",
 			   "", CodecInfo::Win32, "mjpeg",
 			   CodecInfo::Video, CodecInfo::Both
 			   //CodecInfo::Video, CodecInfo::Decode
@@ -600,22 +598,22 @@ static void add_pegas(avm::vector<CodecInfo>& ci)
     static const fourcc_t pim1_codecs[] = {
 	fccPIM1,
 	0 };
-    ci.push_back(CodecInfo(pvw2_codecs, "PicVideo [PVW2]", "pvwv220.dll",
+    ci.push_back(CodecInfo(pvw2_codecs, "W32 PicVideo [PVW2]", "pvwv220.dll",
 			   none_about, CodecInfo::Win32, "picvideo",
 			   //CodecInfo::Video, CodecInfo::Both
 			   CodecInfo::Video, CodecInfo::Decode
 			  ));
-    ci.push_back(CodecInfo(mjpg_codecs, "PicVideo [MJPG]", "pvmjpg21.dll",
+    ci.push_back(CodecInfo(mjpg_codecs, "W32 PicVideo [MJPG]", "pvmjpg21.dll",
 			   none_about, CodecInfo::Win32, "pv_mjpg",
 			   //CodecInfo::Video, CodecInfo::Both
 			   CodecInfo::Video, CodecInfo::Decode
 			  ));
-    ci.push_back(CodecInfo(pimj_codecs, "PicVideo [PIMJ]", "pvljpg20.dll",
+    ci.push_back(CodecInfo(pimj_codecs, "W32 PicVideo [PIMJ]", "pvljpg20.dll",
 			   none_about, CodecInfo::Win32, "pv_pimj",
 			   //CodecInfo::Video, CodecInfo::Both
 			   CodecInfo::Video, CodecInfo::Decode
 			  ));
-    ci.push_back(CodecInfo(pim1_codecs, "PinnacleS [PIM1]", "avi_pass.ax",
+    ci.push_back(CodecInfo(pim1_codecs, "W32 PinnacleS [PIM1]", "avi_pass.ax",
 			   none_about, CodecInfo::DShow_Dec, "pv_pim1",
 			   //CodecInfo::Video, CodecInfo::Both
 			   CodecInfo::Video, CodecInfo::Decode
@@ -629,7 +627,7 @@ static void add_avid(avm::vector<CodecInfo>& ci)
 	mmioFOURCC('A', 'V', 'R', 'n'),
 	mmioFOURCC('A', 'V', 'D', 'J'),
 	0 };
-    ci.push_back(CodecInfo(avrn_codecs, "AVID Codec [AVRn]", "avidavicodec.dll",
+    ci.push_back(CodecInfo(avrn_codecs, "W32 AVID Codec [AVRn]", "avidavicodec.dll",
 			   none_about, CodecInfo::Win32, "avid",
 			   CodecInfo::Video, CodecInfo::Both
 			  ));
@@ -638,7 +636,7 @@ static void add_avid(avm::vector<CodecInfo>& ci)
 static void add_techsmith(avm::vector<CodecInfo>& ci)
 {
     static const fourcc_t tscc_codecs[] = { fccTSCC, fcctscc, 0 };
-    ci.push_back(CodecInfo(tscc_codecs, "TechSmith Screen Capture [TSCC]", "tsccvid.dll",
+    ci.push_back(CodecInfo(tscc_codecs, "W32 TechSmith Screen Capture [TSCC]", "tsccvid.dll",
                            "TechSmith's Screen Capture Codec [TSCC],"
 			   "provides lossless image quality coupled with "
 			   "excellent compression ratios. Since the TSCC is "
@@ -682,7 +680,7 @@ static void add_huffyuv(avm::vector<CodecInfo>& ci)
     //vs.push_back(AttributeInfo("Mode", "Calculation precision mode", (const char**)mjpeg_modes));
     //ci.push_back(CodecInfo(mjpg_codecs, "Motion JPEG DirectShow Decoder", 	"m3jpegdec.ax",mjpg_about, CodecInfo::DShow_Dec, &CLSID_MorganMjpeg, vs));
 
-    ci.push_back(CodecInfo(huffyuv_codecs, "Huffyuv lossless codec [HFYU]",
+    ci.push_back(CodecInfo(huffyuv_codecs, "W32 Huffyuv lossless codec [HFYU]",
 			   "huffyuv.dll",
 			   huffyuv_about, CodecInfo::Win32, "huffyuv",
 			   //CodecInfo::Video, CodecInfo::Decode));
@@ -696,7 +694,7 @@ static void add_vp3(avm::vector<CodecInfo>& ci)
        resource file */
     static const char* vp3_about =
 	"<a href=\"http://www.vp3.com/\">VP3 Codec</a> "
-	"- Version 3.2.1.0<br>\nCopyright (c) 2001 On2 Technologies. "
+	"- Version 3.2.1.0<br>Copyright (c) 2001 On2 Technologies. "
 	"All Rights Reserved. "
 	"<a href=\"http://www.on2.com/\">"
 	"http://www.on2.com</a>";
@@ -719,12 +717,12 @@ static void add_vp3(avm::vector<CodecInfo>& ci)
     images in 'normal' mode ( ICDECOMPRESS ) */
 #if 1
     /* crashing somewhere after IsRect == TRUE */
-    ci.push_back(CodecInfo(apxx_codecs, "VP31(r) DirectShow", "on2.ax",
+    ci.push_back(CodecInfo(apxx_codecs, "W32 VP31(r) DirectShow", "on2.ax",
 			   vp3_about, CodecInfo::DShow_Dec, "vp3ds",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_on2));
 #endif
-    ci.push_back(CodecInfo(apxx_codecs, "VP31(r) Codec", "vp31vfw.dll",
+    ci.push_back(CodecInfo(apxx_codecs, "W32 VP31(r) Codec", "vp31vfw.dll",
 			   vp3_about, CodecInfo::Win32Ex, "vp3",
 			   CodecInfo::Video, CodecInfo::Both, 0, vs_empty, ds));
 }
@@ -744,17 +742,17 @@ static void add_3ivx(avm::vector<CodecInfo>& ci)
     static const fourcc_t ivx_codecs[] = {
 	mmioFOURCC('3', 'I', 'V', '1'), mmioFOURCC('3', 'i', 'v', 'X'),	0
     };
-    ci.push_back(CodecInfo(ivx_codecs, "3ivX", "3ivxdmo.dll",
+    ci.push_back(CodecInfo(ivx_codecs, "W32 3ivX", "3ivxdmo.dll",
 			   none_about, CodecInfo::DMO, "3ivx",
 			   CodecInfo::Video, CodecInfo::Decode,
                            &CLSID_3ivx));
     static const fourcc_t ucod_codecs[] = { mmioFOURCC('U', 'C', 'O', 'D'), 0 };
-    ci.push_back(CodecInfo(ucod_codecs,	"UCOD-ClearVideo", "clrviddd.dll",
+    ci.push_back(CodecInfo(ucod_codecs,	"W32 UCOD-ClearVideo", "clrviddd.dll",
 			   none_about, CodecInfo::Win32, "ucod",
 			   CodecInfo::Video, CodecInfo::Decode));
 
     static const fourcc_t ubmp4_codecs[] = { mmioFOURCC('U', 'M', 'P', '4'), mmioFOURCC('m', 'p', '4', 'v'), 0 };
-    ci.push_back(CodecInfo(ucod_codecs,	"UB Video MPEG 4", "ubvmp4d.dll",
+    ci.push_back(CodecInfo(ucod_codecs,	"W32 UB Video MPEG 4", "ubvmp4d.dll",
 			   none_about, CodecInfo::Win32, "ubmp4",
 			   CodecInfo::Video, CodecInfo::Decode));
 
@@ -764,7 +762,7 @@ static void add_3ivx(avm::vector<CodecInfo>& ci)
 	mmioFOURCC('Q', '1', '.', '1'),
 	mmioFOURCC('q', 'p', 'e', 'q'), 0
     };
-    ci.push_back(CodecInfo(qpeg_codecs,	"Q-Team's QPEG (www.q-team.de)",
+    ci.push_back(CodecInfo(qpeg_codecs,	"W32 Q-Team's QPEG (www.q-team.de)",
 			   "qpeg32.dll",
 			   none_about, CodecInfo::Win32, "qpeg",
 			   CodecInfo::Video, CodecInfo::Decode));
@@ -778,7 +776,7 @@ static void add_3ivx(avm::vector<CodecInfo>& ci)
 	mmioFOURCC('S', 'P', '5', '8'), 0
     };
     ci.push_back(CodecInfo(sp5x_codecs,
-			   "SP5x codec - used by Aiptek MegaCam", "sp5x_32.dll",
+			   "W32 SP5x codec - used by Aiptek MegaCam", "sp5x_32.dll",
 			   none_about, CodecInfo::Win32, "sp5x",
 			   CodecInfo::Video, CodecInfo::Decode));
 
@@ -786,7 +784,7 @@ static void add_3ivx(avm::vector<CodecInfo>& ci)
     /* to be supported */
     static const fourcc_t qtsvq3_codecs[] = { mmioFOURCC('S', 'V', 'Q', '3'), 0 };
     ci.push_back(CodecInfo(sp5x_codecs,
-			   "Qt SVQ3 decoder", "QuickTime.qts",
+			   "W32 Qt SVQ3 decoder", "QuickTime.qts",
 			   none_about, CodecInfo::Win32, "qtvideo",
 			   CodecInfo::Video, CodecInfo::Decode));
 }
@@ -794,7 +792,7 @@ static void add_3ivx(avm::vector<CodecInfo>& ci)
 static void add_audio(avm::vector<CodecInfo>& ci)
 {
     static const fourcc_t msadpcm_codecs[] = { 0x02, 0 };
-    ci.push_back(CodecInfo(msadpcm_codecs, "MS ADPCM", "msadp32.acm",
+    ci.push_back(CodecInfo(msadpcm_codecs, "W32 MS ADPCM", "msadp32.acm",
 			   "A Microsoft implementation of Adaptive "
 			   "Differential Pulse Code Modulation (ADPCM), "
 			   "a common digital audio format capable of "
@@ -808,7 +806,7 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 	{ 0xb5, 0x50, 0x00, 0x60, 0x97, 0x24, 0x2d, 0x8d }
     };
     static const fourcc_t voxware_codecs[] = { 0x75, 0};
-    ci.push_back(CodecInfo(voxware_codecs, "Voxware Metasound", "voxmsdec.ax",
+    ci.push_back(CodecInfo(voxware_codecs, "W32 Voxware Metasound", "voxmsdec.ax",
 			   none_about, CodecInfo::DShow_Dec, "dsvoxware",
 			   CodecInfo::Audio, CodecInfo::Decode,
 			   &CLSID_Voxware));
@@ -819,7 +817,7 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 	{ 0x83, 0x44, 0x00, 0xc0, 0x4f, 0xb9, 0x2e, 0xb7 }
     };
     static const fourcc_t acelp_codecs[] = { 0x130, 0 };
-    ci.push_back(CodecInfo(acelp_codecs, "ACELP(r).net DirectShow", "acelpdec.ax",
+    ci.push_back(CodecInfo(acelp_codecs, "W32 ACELP(r).net DirectShow", "acelpdec.ax",
 			   "A net-based codec using frame-concatenation and "
 			   "interlacing for improved music quality. "
 			   "ACELP(r).net allows a dual-rate bit-rate of 8.5/6.5 "
@@ -829,13 +827,13 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 
     // codec ID ?
     static const fourcc_t anet_codecs[] = { 0x130, 0 };
-    ci.push_back(CodecInfo(anet_codecs, "ACELP(r).net acm", "sl_anet.acm",
+    ci.push_back(CodecInfo(anet_codecs, "W32 ACELP(r).net acm", "sl_anet.acm",
 			   "Sipro Lab Telcom Audio Codec ACELP(r).net codec",
 			   CodecInfo::Win32, "anetacm",
 			   CodecInfo::Audio, CodecInfo::Both));
 
     static const fourcc_t wma_codecs[] = { 0x160, 0x161, 0 };
-    ci.push_back(CodecInfo(wma_codecs, "Windows Media Audio", "divxa32.acm",
+    ci.push_back(CodecInfo(wma_codecs, "W32 Windows Media Audio", "divxa32.acm",
 			   "More fully known as Microsoft(c) Windows Media(tm) "
 			   "audio compression. This is the standard codec for "
 			   "Microsoft Active Streaming Format which combines "
@@ -854,7 +852,7 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 	{ 0xbc, 0xa7, 0xbb, 0x95, 0x5f, 0x56, 0x32, 0x0a }
     };
     static const fourcc_t wma3_codecs[]={ 0x162, 0x160, 0x161, 0};
-    ci.push_back(CodecInfo(wma3_codecs, "Windows Media Audio DMO", "wmadmod.dll",
+    ci.push_back(CodecInfo(wma3_codecs, "W32 Windows Media Audio DMO", "wmadmod.dll",
 			   none_about, CodecInfo::DMO, "wmadmod",
 			   CodecInfo::Audio, CodecInfo::Decode,
 			   &CLSID_WMA3DMO));
@@ -863,7 +861,7 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 	0x27ca0808, 0x01f5, 0x4e7a,
 	{ 0x8b, 0x05, 0x87, 0xf8, 0x07, 0xa2, 0x33, 0xd1 }
     };
-    ci.push_back(CodecInfo(wma3_codecs, "Windows Media Audio 9 DMO", "wma9dmod.dll",
+    ci.push_back(CodecInfo(wma3_codecs, "W32 Windows Media Audio 9 DMO", "wma9dmod.dll",
 			   none_about, CodecInfo::DMO, "wma9dmod",
 			   CodecInfo::Audio, CodecInfo::Decode,
 			   &CLSID_WMA39DMO));
@@ -873,22 +871,22 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 	{ 0x89, 0x48, 0x74, 0x6b, 0x89, 0x59, 0x5d, 0x20 }
     };
     static const fourcc_t wmsp_codecs[] = { 0xa, 0 };
-    ci.push_back(CodecInfo(wmsp_codecs, "Windows Media Audio Speach DMO", "wmspdmod.dll",
+    ci.push_back(CodecInfo(wmsp_codecs, "W32 Windows Media Audio Speach DMO", "wmspdmod.dll",
 			   none_about, CodecInfo::DMO, "wmspdmod",
 			   CodecInfo::Audio, CodecInfo::Decode,
 			   &CLSID_WMSP));
 #if 0
-    ci.push_back(CodecInfo(wma_codecs, "WMA enc", "wmadmoe.dll",
+    ci.push_back(CodecInfo(wma_codecs, "W32 WMA enc", "wmadmoe.dll",
 			   "Winmedadio", CodecInfo::Win32, "wmadmo_enc",
 			   CodecInfo::Audio, CodecInfo::Encode));
 #endif
     static const fourcc_t imc_codecs[] = { 0x401, 0 };
-    ci.push_back(CodecInfo(imc_codecs, "Win32 Intel Music Coder", "imc32.acm",
+    ci.push_back(CodecInfo(imc_codecs, "W32 Intel Music Coder", "imc32.acm",
 			   none_about, CodecInfo::Win32, "imcacm",
 			   CodecInfo::Audio, CodecInfo::Decode));
 
     static const fourcc_t ima_codecs[] = { 0x11, 0 };
-    ci.push_back(CodecInfo(ima_codecs, "Win32 IMA ADPCM", "imaadp32.acm",
+    ci.push_back(CodecInfo(ima_codecs, "W32 IMA ADPCM", "imaadp32.acm",
 			   "An implementation of Adaptive Differential Pulse"
 			   "Code Modulationn (ADPCM), useful for "
 			   "cross-platform audio for multimedia, "
@@ -897,31 +895,31 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 			   CodecInfo::Audio, CodecInfo::Decode));
 
     static const fourcc_t msn_codecs[] = { 0x32, 0 };
-    ci.push_back(CodecInfo(msn_codecs, "Win32 MSN", "msnaudio.acm",
+    ci.push_back(CodecInfo(msn_codecs, "W32 MSN", "msnaudio.acm",
 			   "MSN Audio codec", CodecInfo::Win32, "msnaudioacm",
 			   CodecInfo::Audio, CodecInfo::Decode));
     static const fourcc_t gsm_codecs[] = { 0x31, 0x32, 0 };
-    ci.push_back(CodecInfo(gsm_codecs, "Win32 GSM", "msgsm32.acm",
+    ci.push_back(CodecInfo(gsm_codecs, "W32 GSM", "msgsm32.acm",
 			   "MSN GSM Audio codec", CodecInfo::Win32, "msgsmacm",
 			   CodecInfo::Audio, CodecInfo::Decode));
 
     static const fourcc_t dsp_codecs[] = { 0x22, 0 };
-    ci.push_back(CodecInfo(dsp_codecs, "DSP Group TrueSpeech(TM)", "tssoft32.acm",
+    ci.push_back(CodecInfo(dsp_codecs, "W32 DSP Group TrueSpeech(TM)", "tssoft32.acm",
 			   none_about, CodecInfo::Win32, "truespeechacm",
 			   CodecInfo::Audio, CodecInfo::Decode));
 
     static const fourcc_t lh_codecs[] = { 0x1101, 0x1102, 0x1103, 0x1104, 0 };
-    ci.push_back(CodecInfo(lh_codecs, "Win32 Lernout & Hauspie", "lhacm.acm",
+    ci.push_back(CodecInfo(lh_codecs, "W32 Lernout & Hauspie", "lhacm.acm",
 			   "Lernout & Hauspie  CELP, SCB", CodecInfo::Win32, "lhacm",
 			   CodecInfo::Audio, CodecInfo::Decode));
 
     static const fourcc_t vox_codecs[] = { 0x181c, 0 };
-    ci.push_back(CodecInfo(vox_codecs, "VoxWare RT24 speech codec", "nsrt2432.acm",
+    ci.push_back(CodecInfo(vox_codecs, "W32 VoxWare RT24 speech codec", "nsrt2432.acm",
 			   none_about, CodecInfo::Win32, "voxwarert24acm",
 			   CodecInfo::Audio, CodecInfo::Decode));
 
     static const fourcc_t alf2_codecs[] = { 0x1fc4, 0 };
-    ci.push_back(CodecInfo(alf2_codecs, "ALF2 codec", "alf2cd.acm",
+    ci.push_back(CodecInfo(alf2_codecs, "W32 ALF2 codec", "alf2cd.acm",
 			   "http://www.nctsoft.com/products/NCTALFCD/"
 			   "jdp@mail.sonofon.dk",
 			   CodecInfo::Win32, "alf2acm",
@@ -933,7 +931,7 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 	{0x96, 0x65, 0x00, 0xF0, 0xBF, 0x62, 0x92, 0xE5}
     };
     static const fourcc_t vorbis_codecs[] = { 0xFFFE, 0 };
-    ci.push_back(CodecInfo(vorbis_codecs, "Win32 Vorbis decoder", "vorbis.acm",
+    ci.push_back(CodecInfo(vorbis_codecs, "W32 Vorbis decoder", "vorbis.acm",
 			   "Vorbis Audio codec", CodecInfo::Win32, "vorbisacm",
 			   CodecInfo::Audio, CodecInfo::Decode,
 			   &CLSID_Vorbis));
@@ -951,20 +949,20 @@ static void add_audio(avm::vector<CodecInfo>& ci)
 	{ 0x86, 0x0e, 0x00, 0xA0, 0x24, 0xCF, 0xEF, 0x6D }
     };
     // DS doesn't work
-    ci.push_back(CodecInfo(mpeg_codecs, "Win32 MPEG Layer-3 DS", "l3codecx.ax",
+    ci.push_back(CodecInfo(mpeg_codecs, "W32 MPEG Layer-3 DS", "l3codecx.ax",
 			   none_about, CodecInfo::DShow_Dec, "mp3ds",
 			   CodecInfo::Audio, CodecInfo::Decode,
 			   &CLSID_Mpeg));
 #endif
     // acm version is somewhat problematic - disable
-    ci.push_back(CodecInfo(mpeg_codecs, "Win32 MPEG Layer-3", "l3codeca.acm",
+    ci.push_back(CodecInfo(mpeg_codecs, "W32 MPEG Layer-3", "l3codeca.acm",
 			   none_about, CodecInfo::Win32, "mp3acm",
 			   CodecInfo::Audio, CodecInfo::Decode));
 #endif
 #if 0
     // this works but only as a last resource - it has quite poor quality
     static const fourcc_t mpeg_codecs[] = { 0x55, 0 };
-    ci.push_back(CodecInfo(mpeg_codecs, "MPEG Layer-3", "divxa32.acm",
+    ci.push_back(CodecInfo(mpeg_codecs, "W32 MPEG Layer-3", "divxa32.acm",
 			   none_about, CodecInfo::Win32, "divxmp3",
 			   CodecInfo::Audio, CodecInfo::Decode));
 #endif
@@ -1002,11 +1000,11 @@ static void win32_FillPlugins(avm::vector<CodecInfo>& ci)
 	"Very old video codec, usually "
 	"available as a part of Windows.";
     static const fourcc_t cvid_codecs[] = { fccCVID, fcccvid, 0 };
-    ci.push_back(CodecInfo(cvid_codecs, "Cinepak Video", "iccvid.dll",
+    ci.push_back(CodecInfo(cvid_codecs, "W32 Cinepak Video", "iccvid.dll",
 			   cvid_about, CodecInfo::Win32, "cvid"));
 
     static const fourcc_t i263_codecs[] = { fccI263, fcci263, 0 };
-    ci.push_back(CodecInfo(i263_codecs,	"I263", "i263_32.drv",
+    ci.push_back(CodecInfo(i263_codecs,	"W32 I263", "i263_32.drv",
 			   none_about, CodecInfo::Win32, "i263"));
 
     static const GUID CLSID_U263DecompressorCF = {
@@ -1014,36 +1012,36 @@ static void win32_FillPlugins(avm::vector<CodecInfo>& ci)
 	{ 0x9d, 0x5a, 0x00, 0x50, 0x04, 0x79, 0x6c, 0xc0}
     };
     static const fourcc_t u263_codecs[] = { fccU263, 0 };
-    ci.push_back(CodecInfo(i263_codecs,	"U263", "ubv263d+.ax",
+    ci.push_back(CodecInfo(i263_codecs,	"W32 U263", "ubv263d+.ax",
 			   none_about, CodecInfo::DShow_Dec, "u263",
                            CodecInfo::Video, CodecInfo::Both,
 			   &CLSID_U263DecompressorCF));
 
     static const fourcc_t mwv1_codecs[] = { fccMWV1, 0 };
-    ci.push_back(CodecInfo(mwv1_codecs,	"Motion Wavelets",
+    ci.push_back(CodecInfo(mwv1_codecs,	"W32 Motion Wavelets",
 			   "icmw_32.dll",
 			   "Aware Motion Wavelets Video Codec [MWV1]",
 			   CodecInfo::Win32, "mwv1",
 			   CodecInfo::Video, CodecInfo::Both));
 
     static const fourcc_t mszh_codecs[] = { fccMSZH, 0 };
-    ci.push_back(CodecInfo(mszh_codecs,	"AVI Mszh", "avimszh.dll",
+    ci.push_back(CodecInfo(mszh_codecs,	"W32 AVI Mszh", "avimszh.dll",
 			   none_about, CodecInfo::Win32, "mszh",
 			   CodecInfo::Video, CodecInfo::Both));
 
     static const fourcc_t zlib_codecs[] = { fccZLIB, 0 };
-    ci.push_back(CodecInfo(zlib_codecs,	"AVI Zlib", "avizlib.dll",
+    ci.push_back(CodecInfo(zlib_codecs,	"W32 AVI Zlib", "avizlib.dll",
 			   none_about, CodecInfo::Win32, "zlib",
 			   CodecInfo::Video, CodecInfo::Both));
 
     static const fourcc_t m261_codecs[] = { fccM261, fccm261, 0 };
-    ci.push_back(CodecInfo(m261_codecs,	"M261", "msh261.drv",
+    ci.push_back(CodecInfo(m261_codecs,	"W32 M261", "msh261.drv",
 			   none_about, CodecInfo::Win32, "m261",
                            // crash with encode FIXME
 			   CodecInfo::Video, CodecInfo::Decode));
 
     static const fourcc_t msrle_codecs[] = { 1, 0 };
-    ci.push_back(CodecInfo(msrle_codecs, "MS RLE", "msrle32.dll",
+    ci.push_back(CodecInfo(msrle_codecs, "W32 MS RLE", "msrle32.dll",
 			   none_about, CodecInfo::Win32, "msrlevfw",
 			   CodecInfo::Video, CodecInfo::Both));
 
@@ -1057,20 +1055,26 @@ static void win32_FillPlugins(avm::vector<CodecInfo>& ci)
 	{ 0x83, 0xaa, 0x00, 0x00, 0x92, 0x90, 0x01, 0x84 }
     };
     static const fourcc_t tm20_codecs[] = { fccTM20, 0 };
-    ci.push_back(CodecInfo(tm20_codecs,	"TrueMotion 2.0 DS Decompressor",
+    ci.push_back(CodecInfo(tm20_codecs,	"W32 TrueMotion 2.0 DS Decompressor",
 			   "tm20dec.ax",
 			   none_about, CodecInfo::DShow_Dec, "tm20ds",
 			   CodecInfo::Video, CodecInfo::Decode,
 			   &CLSID_Tm20));
 #endif
 #if 0
-    ci.push_back(CodecInfo(tm20_codecs,	"TrueMotion 2.0 Decompressor",
+    ci.push_back(CodecInfo(tm20_codecs,	"W32 TrueMotion 2.0 Decompressor",
 			   "tm2x.dll",
 			   none_about, CodecInfo::Win32, "tm20",
 			   CodecInfo::Video, CodecInfo::Decode));
 #endif
-    static const fourcc_t cram_codecs[] = { fccCRAM, fcccram, fccMSVC, 0 };
-    ci.push_back(CodecInfo(cram_codecs,	"Microsoft Video 1", "msvidc32.dll",
+    static const fourcc_t cram_codecs[] = {
+	fccCRAM, fcccram, fccMSVC,
+	mmioFOURCC('m', 's', 'v', 'c'),
+	mmioFOURCC('w', 'h', 'a', 'm'),
+	mmioFOURCC('W', 'H', 'A', 'M'),
+	0
+    };
+    ci.push_back(CodecInfo(cram_codecs,	"W32 Microsoft Video 1", "msvidc32.dll",
 			   none_about, CodecInfo::Win32, "cram",
                            CodecInfo::Video, CodecInfo::Decode));
 }
