@@ -6,23 +6,15 @@
  * (In case it's not available - modify Makefile.am apropriately)
  * It's good idea to use single threaded operation mode
  * so modify Cache.cpp to no use thread for precaching #define NOTHREADS
- *
- * to use this program with mpatrol:
- *    mpatrol --show-all --leak-table testvideo
- * with libefence:
- *    LD_PRELOAD=/usr/lib/libefence.so.0 testvideo
- *
  */
 
 #include <avifile.h>
 #include <avm_except.h>
 #include <avm_fourcc.h>
+#include <videodecoder.h>
+#include <image.h>
 #include <utils.h>
 
-#ifdef USE_MPATROL
-#include <mpatrol.h>
-#endif
-
 #include <stdio.h>
 
 const char* filename = "/net/hdd2/movies/test4/vp30_logo.avi";
