@@ -38,7 +38,8 @@ DS_VideoDecoder::DS_VideoDecoder(const CodecInfo& info, const BITMAPINFOHEADER&
     :IVideoDecoder(info, format), m_sVhdr2(0), m_pIDivx4(0), m_iStatus(0),
     m_iLastPPMode(0), m_iLastBrightness(0), m_iLastContrast(0),
     m_iLastSaturation(0), m_iLastHue(0), 
-    m_CType(CT_NONE), m_bHaveUpsideDownRGB(true), m_bFlip(flip)
+    m_CType(CT_NONE), m_bHaveUpsideDownRGB(true),
+    m_bSetFlg(false), m_bFlip(flip)
 {
     unsigned bihs = (m_pFormat->biSize < (int) sizeof(BITMAPINFOHEADER)) ?
 	sizeof(BITMAPINFOHEADER) : m_pFormat->biSize;
@@ -141,7 +142,7 @@ int DS_VideoDecoder::init()
 	break;
     default:
 	{
-	    struct ct {
+	    static const struct ct {
 		unsigned int bits;
 		fourcc_t fcc;
 		GUID subtype;
@@ -158,13 +159,12 @@ int DS_VideoDecoder::init()
 	    };
 	    m_Caps = CAP_NONE;
 
-	    for (ct* c = check; c->bits; c++)
+	    for (const ct* c = check; c->bits; c++)
 	    {
 		m_sVhdr2->bmiHeader.biBitCount = c->bits;
 		m_sVhdr2->bmiHeader.biCompression = c->fcc;
 		m_sDestType.subtype = c->subtype;
-		int r = m_pDS_Filter->m_pOutputPin->vt->QueryAccept(m_pDS_Filter->m_pOutputPin, &m_sDestType);
-		if (!r)
+		if (0 == m_pDS_Filter->m_pOutputPin->vt->QueryAccept(m_pDS_Filter->m_pOutputPin, &m_sDestType))
 		    m_Caps = (CAPS)(m_Caps | c->cap);
 	    }
 	    m_sVhdr2->bmiHeader.biBitCount = 24;
@@ -412,7 +412,7 @@ int DS_VideoDecoder::SetDestFmt(int bits, fourcc_t csp)
     if (m_sVhdr2->bmiHeader.biCompression == 3)
         m_sDestType.cbFormat += 12;
 
-    struct ct {
+    static const struct ct {
 	fourcc_t fcc;
         CAPS cap;
     } map[] =
@@ -425,9 +425,9 @@ int DS_VideoDecoder::SetDestFmt(int bits, fourcc_t csp)
 	{ 0 }
     };
 
-    int result = 0;
+    int result;
     bool should_test = true;
-    for (ct* c = map; c->fcc; c++)
+    for (const ct* c = map; c->fcc; c++)
     {
 	if (c->fcc == csp)
 	{
@@ -436,8 +436,7 @@ int DS_VideoDecoder::SetDestFmt(int bits, fourcc_t csp)
             break;
 	}
     }
-    if (should_test)
-	result = m_pDS_Filter->m_pOutputPin->vt->QueryAccept(m_pDS_Filter->m_pOutputPin, &m_sDestType);
+    result = (should_test) ? m_pDS_Filter->m_pOutputPin->vt->QueryAccept(m_pDS_Filter->m_pOutputPin, &m_sDestType) : 0;
 
     if (result != 0)
     {
