@@ -12,6 +12,7 @@
 #include <utils.h>
 #include <avm_creators.h>
 #include <avm_except.h>
+#include <avm_stl.h>
 
 #define DECLARE_REGISTRY_SHORTCUT
 #include <configfile.h>
@@ -306,7 +307,7 @@ m_pProgress(0), m_ccap(ccap), m_pAllocator(0),
 m_conf(*conf), error(""), segment_flag(0), vid_clear(0), aud_clear(0)
 {
   segmenting_name="";
-    starttime=longcount();
+    starttime=avm_get_time_us();
 
     if(ccap)
     {
@@ -410,7 +411,7 @@ void CaptureProcess::capwriter(void* arg, const char* data)
     if(a.lastccstring == data)
 	return;
     char s[4096];
-    long long curtime=longcount();
+    long long curtime=avm_get_time_us();
     int frame1=(int) ((a.lastcctime-a.starttime)*a.m_conf.fps/(1000.*freq));
     int frame2=(int) ((curtime-a.starttime)*a.m_conf.fps/(1000.*freq));
     if(a.lastccstring.size()==0)
@@ -468,12 +469,12 @@ void* CaptureProcess::vidcap()
 
     while (!m_quit)
     {
-	int64_t currenttime = longcount();
+	int64_t currenttime = avm_get_time_us();
 //	cerr<<currenttime<<" "<<starttime<<" "<<fps<<std::endl;
-//	cerr<<to_float(currenttime, starttime)*fps<<" "<<cnt<<std::endl;
+//	cerr<<avm_get_time_diff(currenttime, starttime)*fps<<" "<<cnt<<std::endl;
 //	double freq=550000.;
 	double dist=double(currenttime-starttime)/(freq*1000.);
-//	double dist=to_float(currenttime, starttime);
+//	double dist=avm_get_time_diff(currenttime, starttime);
 //	cerr<<dist<<" "<<freq<<std::endl;
 	if (dist * fps < cnt || m_qvid.size() >= (m_qvid.capacity() - 1))
 	{
@@ -575,7 +576,7 @@ void* CaptureProcess::vidcap()
 	    cap_drop++;
 	}
 	ch.timestamp=dist;
-
+        ch.size = 0;
 	m_qvid.push(ch);
 	cnt++;
 //	if(cnt%100==0)
@@ -603,7 +604,7 @@ void* CaptureProcess::audcap()
 	    m_pProgress->setTimestampShift(timestamp_shift);
 	}
 	ch.size = m_pDsp->read(ch.data, audioblock);
-	int64_t ct = longcount();
+	int64_t ct = avm_get_time_us();
 	//double freq=550000.;
 
 	//printf("ACT  %d  %d   %f    %f\n", audioblock, m_pDsp->getSize(), abps, timestamp_shift);
@@ -621,7 +622,7 @@ void* CaptureProcess::audcap()
 #ifdef AVICAP_PARANOIA1
 #if 0
 	char tbuf[300];
-	sprintf(tbuf,"TIME %f   %f  %f\n", to_float(ct, starttime) - ch.timestamp, ch.timestamp, timestamp_shift);
+	sprintf(tbuf,"TIME %f   %f  %f\n", avm_get_time_diff(ct, starttime) - ch.timestamp, ch.timestamp, timestamp_shift);
 	ParanoiaLog(tbuf);
 
 	sprintf(tbuf,"ch.timestamp=%f  bufsize/abps=%f\n",ch.timestamp,bufsize / abps);
@@ -716,7 +717,7 @@ void* CaptureProcess::writer()
 //	stream=file->AddStream(AviStream::Video);
 //	ve.Init(fccIV50, (const char*)&bh);
     }
-    catch (FatalError& e)
+    catch (avm::FatalError& e)
     {
 	e.Print();
 	error=e.GetDesc();
@@ -769,7 +770,7 @@ void* CaptureProcess::writer()
 	    comp_drop++;
 
 	    if(m_pProgress)
-		m_pProgress->update(longcount()-starttime,
+		m_pProgress->update(avm_get_time_us()-starttime,
 				    vid_time, aud_time,
 				    audiodata, file->GetFileSize(),
 				    videodata-cnt, 0, m_pAllocator->used_frames,
@@ -816,7 +817,7 @@ void* CaptureProcess::writer()
 	    }
 	    double audio_error=audiodata/abps-ch.timestamp;
 	    if(m_pProgress){
-		m_pProgress->update(longcount()-starttime, vid_time, aud_time,
+		m_pProgress->update(avm_get_time_us()-starttime, vid_time, aud_time,
 				    audiodata, file->GetFileSize(), videodata-cnt,
 				    -1, m_pAllocator->used_frames, cap_drop,
 				    comp_drop, file->GetFileName());
@@ -875,7 +876,7 @@ void* CaptureProcess::writer()
 			uiSize |= 0x40000000;
 		}
 		if(m_pProgress)
-		    m_pProgress->update(longcount()-starttime, vid_time, aud_time,
+		    m_pProgress->update(avm_get_time_us()-starttime, vid_time, aud_time,
 					audiodata, file->GetFileSize(), videodata-cnt,
 					uiSize, m_pAllocator->used_frames, cap_drop,
 					comp_drop, file->GetFileName());
@@ -884,7 +885,7 @@ void* CaptureProcess::writer()
 		    videodata++;
 		    stream->AddFrame(im, &uiSize);
 		    if(m_pProgress)
-			m_pProgress->update(longcount()-starttime, vid_time, aud_time,
+			m_pProgress->update(avm_get_time_us()-starttime, vid_time, aud_time,
 					    audiodata, file->GetFileSize(), videodata-cnt,
 					    uiSize, m_pAllocator->used_frames, cap_drop,
 					    comp_drop, file->GetFileName());
