@@ -37,8 +37,8 @@
 static const struct restab {
     int id;
     int w,h;
-    const char * lname;
-    const char * sname;
+    const char* lname;
+    const char* sname;
 } cv_dimensions[] = {
     { 0, 160, 120, "160 x 120 (1/4 NTSC)", "160 x 120" },
     { 1, 192, 144, "192 x 144 (1/4 PAL)" , "192 x 144" },
@@ -80,7 +80,7 @@ VidConfig::VidConfig( QWidget* parent, v4lxif* v4l, V4LWindow* w)
 
     _VideoChannel->clear();
     if (v4l)
-	for(int j=0; j<v4l->capCapChannelC(); j++)
+	for(int j = 0; j < v4l->capCapChannelC(); j++)
 	    _VideoChannel->insertItem(v4l->capChannelName(j));
     _VideoChannel->setCurrentItem( RI("Channel", 1) );
     _Colorspace->setCurrentItem( RI("Colorspace", 0) );
@@ -243,7 +243,7 @@ void VidConfig::savePage(int page)
     switch(page)
     {
     case 0:
-	WS("CapDev", _CapDevice->text());
+	WS("CaptureDevice", _CapDevice->text());
 	WS("AudioDevice", _AudDevice->text());
 	WI("Resolution", _Resolution->currentItem());
 	WI("Channel", _VideoChannel->currentItem());
@@ -278,7 +278,6 @@ void VidConfig::savePage(int page)
 
 	    regname=QString().sprintf("DirPool-%02d-Path",i);
 	    WS(regname,"NONE");
-
 	}
 
 	break;
